@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -194,31 +194,19 @@ public class FormatData_be extends ListResourceBundle {
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0433\u043e\u0434" },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_japanese_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "\u0447\u0430\u0441\u0430\u0432\u044b \u043f\u043e\u044f\u0441" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u043c\u0443\u0441\u0443\u043b\u044c\u043c\u0430\u043d\u0441\u043a\u0456 \u0441\u0432\u0435\u0446\u043a\u0456 \u043a\u0430\u043b\u044f\u043d\u0434\u0430\u0440" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
             { "timezone.regionFormat.standard", "\u0421\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u044b \u0447\u0430\u0441: {0}" },
             { "calendarname.japanese", "\u044f\u043f\u043e\u043d\u0441\u043a\u0456 \u043a\u0430\u043b\u044f\u043d\u0434\u0430\u0440" },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "Eras", metaValue_Eras },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
             { "long.Eras",
                 new String[] {
                     "\u0434\u0430 \u043d\u0430\u0440\u0430\u0434\u0436\u044d\u043d\u043d\u044f \u0425\u0440\u044b\u0441\u0442\u043e\u0432\u0430",
@@ -226,9 +214,7 @@ public class FormatData_be extends ListResourceBundle {
                 }
             },
             { "islamic.DayNames", metaValue_DayNames },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_japanese_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "field.weekday", "\u0434\u0437\u0435\u043d\u044c \u0442\u044b\u0434\u043d\u044f" },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
@@ -256,34 +242,16 @@ public class FormatData_be extends ListResourceBundle {
             },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_japanese_DatePatterns },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0445\u0432\u0456\u043b\u0456\u043d\u0430" },
             { "field.era", "\u044d\u0440\u0430" },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "timezone.hourFormat", "+HH.mm;-HH.mm" },
             { "calendarname.roc", "\u043a\u0430\u043b\u044f\u043d\u0434\u0430\u0440 \u041c\u0456\u043d\u044c\u0433\u043e" },
             { "islamic.DatePatterns", metaValue_japanese_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
             { "field.month", "\u043c\u0435\u0441\u044f\u0446" },
-            { "buddhist.DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM y GGGG",
-                    "d MMMM y GGGG",
-                    "d MMM y GGGG",
-                    "d.M.yy",
-                }
-            },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434\u0430" },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "field.week", "\u0442\u044b\u0434" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
             { "NumberPatterns",
@@ -294,56 +262,9 @@ public class FormatData_be extends ListResourceBundle {
                 }
             },
             { "roc.DatePatterns", metaValue_japanese_DatePatterns },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.islamic", "\u043c\u0443\u0441\u0443\u043b\u044c\u043c\u0430\u043d\u0441\u043a\u0456 \u043a\u0430\u043b\u044f\u043d\u0434\u0430\u0440" },
-            { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
-            { "java.time.roc.DatePatterns", metaValue_java_time_japanese_DatePatterns },
-            { "java.time.buddhist.DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM y G",
-                    "d MMMM y G",
-                    "d MMM y G",
-                    "d.M.yy",
-                }
-            },
-            { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "\u041b\u0435\u0442\u043d\u0456 \u0447\u0430\u0441: {0}" },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM y '\u0433'.",
-                    "d MMMM y '\u0433'.",
-                    "d.MM.y",
-                    "d.MM.yy",
-                }
-            },
-            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames", metaValue_DayNames },
-            { "field.hour", "\u0433\u0430\u0434\u0437\u0456\u043d\u0430" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "calendarname.buddhist", "\u0431\u0443\u0434\u044b\u0439\u0441\u043a\u0456 \u043a\u0430\u043b\u044f\u043d\u0434\u0430\u0440" },
-            { "standalone.MonthNames",
-                new String[] {
-                    "\u0441\u0442\u0443\u0434\u0437\u0435\u043d\u044c",
-                    "\u043b\u044e\u0442\u044b",
-                    "\u0441\u0430\u043a\u0430\u0432\u0456\u043a",
-                    "\u043a\u0440\u0430\u0441\u0430\u0432\u0456\u043a",
-                    "\u043c\u0430\u0439",
-                    "\u0447\u044d\u0440\u0432\u0435\u043d\u044c",
-                    "\u043b\u0456\u043f\u0435\u043d\u044c",
-                    "\u0436\u043d\u0456\u0432\u0435\u043d\u044c",
-                    "\u0432\u0435\u0440\u0430\u0441\u0435\u043d\u044c",
-                    "\u043a\u0430\u0441\u0442\u0440\u044b\u0447\u043d\u0456\u043a",
-                    "\u043b\u0456\u0441\u0442\u0430\u043f\u0430\u0434",
-                    "\u0441\u043d\u0435\u0436\u0430\u043d\u044c",
-                    "",
-                }
-            },
             { "standalone.MonthAbbreviations",
                 new String[] {
                     "\u0441\u0442\u0443",
@@ -362,15 +283,132 @@ public class FormatData_be extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "\u0427\u0430\u0441: {0}" },
-            { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0442\u044b\u0441\u044f\u0447\u0430",
+                    "00 \u0442\u044b\u0441\u044f\u0447\u0430",
+                    "000 \u0442\u044b\u0441\u044f\u0447\u0430",
+                    "0 \u043c\u0456\u043b\u044c\u0451\u043d",
+                    "00 \u043c\u0456\u043b\u044c\u0451\u043d",
+                    "000 \u043c\u0456\u043b\u044c\u0451\u043d",
+                    "0 \u043c\u0456\u043b\u044c\u044f\u0440\u0434",
+                    "00 \u043c\u0456\u043b\u044c\u044f\u0440\u0434",
+                    "000 \u043c\u0456\u043b\u044c\u044f\u0440\u0434",
+                    "0 \u0442\u0440\u044b\u043b\u044c\u0451\u043d",
+                    "00 \u0442\u0440\u044b\u043b\u044c\u0451\u043d",
+                    "000 \u0442\u0440\u044b\u043b\u044c\u0451\u043d",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "standalone.QuarterNames", metaValue_QuarterNames },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "TimePatterns", metaValue_TimePatterns },
+            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "field.zone", "\u0447\u0430\u0441\u0430\u0432\u044b \u043f\u043e\u044f\u0441" },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "Eras", metaValue_Eras },
+            { "roc.DayNames", metaValue_DayNames },
+            { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_japanese_DatePatterns },
+            { "field.weekday", "\u0434\u0437\u0435\u043d\u044c \u0442\u044b\u0434\u043d\u044f" },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "timezone.hourFormat", "+HH.mm;-HH.mm" },
+            { "japanese.DayNames", metaValue_DayNames },
+            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNames", metaValue_DayNames },
+            { "buddhist.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y GGGG",
+                    "d MMMM y GGGG",
+                    "d MMM y GGGG",
+                    "d.M.yy",
+                }
+            },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "field.week", "\u0442\u044b\u0434" },
+            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
+            { "buddhist.QuarterNames", metaValue_QuarterNames },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "roc.DayNarrows", metaValue_DayNarrows },
+            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "java.time.roc.DatePatterns", metaValue_java_time_japanese_DatePatterns },
+            { "java.time.buddhist.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y G",
+                    "d MMMM y G",
+                    "d MMM y G",
+                    "d.M.yy",
+                }
+            },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u0442\u044b\u0441'.'",
+                    "00\u00a0\u0442\u044b\u0441'.'",
+                    "000\u00a0\u0442\u044b\u0441'.'",
+                    "0\u00a0\u043c\u043b\u043d",
+                    "00\u00a0\u043c\u043b\u043d",
+                    "000\u00a0\u043c\u043b\u043d",
+                    "0\u00a0\u043c\u043b\u0440\u0434",
+                    "00\u00a0\u043c\u043b\u0440\u0434",
+                    "000\u00a0\u043c\u043b\u0440\u0434",
+                    "0\u00a0\u0442\u0440\u043b\u043d",
+                    "00\u00a0\u0442\u0440\u043b\u043d",
+                    "000\u00a0\u0442\u0440\u043b\u043d",
+                }
+            },
+            { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "timezone.regionFormat.daylight", "\u041b\u0435\u0442\u043d\u0456 \u0447\u0430\u0441: {0}" },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y '\u0433'.",
+                    "d MMMM y '\u0433'.",
+                    "d.MM.y",
+                    "d.MM.yy",
+                }
+            },
+            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.DayNames", metaValue_DayNames },
+            { "field.hour", "\u0433\u0430\u0434\u0437\u0456\u043d\u0430" },
+            { "calendarname.buddhist", "\u0431\u0443\u0434\u044b\u0439\u0441\u043a\u0456 \u043a\u0430\u043b\u044f\u043d\u0434\u0430\u0440" },
+            { "standalone.MonthNames",
+                new String[] {
+                    "\u0441\u0442\u0443\u0434\u0437\u0435\u043d\u044c",
+                    "\u043b\u044e\u0442\u044b",
+                    "\u0441\u0430\u043a\u0430\u0432\u0456\u043a",
+                    "\u043a\u0440\u0430\u0441\u0430\u0432\u0456\u043a",
+                    "\u043c\u0430\u0439",
+                    "\u0447\u044d\u0440\u0432\u0435\u043d\u044c",
+                    "\u043b\u0456\u043f\u0435\u043d\u044c",
+                    "\u0436\u043d\u0456\u0432\u0435\u043d\u044c",
+                    "\u0432\u0435\u0440\u0430\u0441\u0435\u043d\u044c",
+                    "\u043a\u0430\u0441\u0442\u0440\u044b\u0447\u043d\u0456\u043a",
+                    "\u043b\u0456\u0441\u0442\u0430\u043f\u0430\u0434",
+                    "\u0441\u043d\u0435\u0436\u0430\u043d\u044c",
+                    "",
+                }
+            },
+            { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
