@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -166,10 +166,6 @@ public class FormatData_gu extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
-               "BC",
-               "BE",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM, G y",
                "d MMMM, G y",
@@ -186,20 +182,15 @@ public class FormatData_gu extends ListResourceBundle {
                "AM",
                "PM",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u0a86\u0ab0.\u0a93.\u0ab8\u0ac0. \u0aaa\u0ab9\u0ac7\u0ab2\u0abe\u0a82",
                "\u0a86\u0ab0.\u0a93.\u0ab8\u0ac0.",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
-               "",
-               "AH",
-            };
         final String metaValue_calendarname_gregorian = "\u0a97\u0acd\u0ab0\u0ac7\u0a97\u0acb\u0ab0\u0abf\u0a85\u0aa8 \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0ab5\u0ab0\u0acd\u0ab7" },
             { "calendarname.islamic-umalqura", "\u0a87\u0ab8\u0acd\u0ab2\u0abe\u0aae\u0abf\u0a95 \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0 (\u0a89\u0aae\u0aae \u0a85\u0ab2-\u0a95\u0ac1\u0ab0\u0abe)" },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -207,7 +198,7 @@ public class FormatData_gu extends ListResourceBundle {
             { "calendarname.islamic-civil", "\u0a87\u0ab8\u0acd\u0ab2\u0abe\u0aae\u0abf\u0a95-\u0aa8\u0abe\u0a97\u0ab0\u0abf\u0a95 \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0" },
             { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "\u0a87 \u0ab8 \u0aaa\u0ac1",
@@ -215,7 +206,7 @@ public class FormatData_gu extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat.standard", "{0} \u0aae\u0abe\u0aa8\u0a95 \u0ab8\u0aae\u0aaf" },
-            { "calendarname.japanese", "\u0a9c\u0abe\u0aaa\u0abe\u0aa8\u0abf\u0a9d \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0" },
+            { "calendarname.japanese", "\u0a9c\u0abe\u0aaa\u0abe\u0aa8\u0ac0\u0a9d \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -275,27 +266,11 @@ public class FormatData_gu extends ListResourceBundle {
                     "",
                 }
             },
-            { "arab.NumberElements",
-                new String[] {
-                    "\u066b",
-                    "\u066c",
-                    "\u061b",
-                    "\u066a\u061c",
-                    "\u0660",
-                    "#",
-                    "\u061c-",
-                    "\u0627\u0633",
-                    "\u0609",
-                    "\u221e",
-                    "NaN",
-                }
-            },
             { "calendarname.roc", "\u0aae\u0abf\u0a82\u0a97\u0ac1\u0a93 \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
             { "field.month", "\u0aae\u0ab9\u0abf\u0aa8\u0acb" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u0ab8\u0ac7\u0a95\u0aa8\u0acd\u0aa1" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -308,10 +283,31 @@ public class FormatData_gu extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0a87\u0ab8\u0acd\u0ab2\u0abe\u0aae\u0abf\u0a95 \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} \u0ab8\u0aae\u0aaf" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0ab9\u0a9c\u0abe\u0ab0",
+                    "00 \u0ab9\u0a9c\u0abe\u0ab0",
+                    "0 \u0ab2\u0abe\u0a96",
+                    "00 \u0ab2\u0abe\u0a96",
+                    "0 \u0a95\u0ab0\u0acb\u0aa1",
+                    "00 \u0a95\u0ab0\u0acb\u0aa1",
+                    "0 \u0a85\u0aac\u0a9c",
+                    "00 \u0a85\u0aac\u0a9c",
+                    "0 \u0aa8\u0abf\u0a96\u0ab0\u0acd\u0ab5",
+                    "0 \u0aae\u0ab9\u0abe\u0aaa\u0aa6\u0acd\u0aae",
+                    "0 \u0ab6\u0a82\u0a95\u0ac1",
+                    "0 \u0a9c\u0ab2\u0aa7\u0abf",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -319,13 +315,13 @@ public class FormatData_gu extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u0ab8\u0aae\u0aaf \u0a9d\u0acb\u0aa8" },
             { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "Eras",
                 new String[] {
                     "\u0a88.\u0ab8.\u0aaa\u0ac2\u0ab0\u0acd\u0ab5\u0ac7",
@@ -338,7 +334,6 @@ public class FormatData_gu extends ListResourceBundle {
             { "field.weekday", "\u0a85\u0aa0\u0ab5\u0abe\u0aa1\u0abf\u0aaf\u0abe\u0aa8\u0acb \u0aa6\u0abf\u0ab5\u0ab8" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
@@ -346,7 +341,6 @@ public class FormatData_gu extends ListResourceBundle {
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
             { "field.week", "\u0a85\u0aa0\u0ab5\u0abe\u0aa1\u0abf\u0aaf\u0ac1\u0a82" },
             { "gujr.NumberElements",
                 new String[] {
@@ -370,6 +364,25 @@ public class FormatData_gu extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u0ab9\u0a9c\u0abe\u0ab0",
+                    "00\u00a0\u0ab9\u0a9c\u0abe\u0ab0",
+                    "0\u00a0\u0ab2\u0abe\u0a96",
+                    "00\u00a0\u0ab2\u0abe\u0a96",
+                    "0\u00a0\u0a95\u0ab0\u0acb\u0aa1",
+                    "00\u00a0\u0a95\u0ab0\u0acb\u0aa1",
+                    "0\u00a0\u0a85\u0aac\u0a9c",
+                    "00\u00a0\u0a85\u0aac\u0a9c",
+                    "0\u00a0\u0aa8\u0abf\u0a96\u0ab0\u0acd\u0ab5",
+                    "0\u00a0\u0aae\u0ab9\u0abe\u0aaa\u0aa6\u0acd\u0aae",
+                    "0\u00a0\u0ab6\u0a82\u0a95\u0ac1",
+                    "0\u00a0\u0a9c\u0ab2\u0aa7\u0abf",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} \u0aa6\u0abf\u0ab5\u0ab8 \u0ab8\u0aae\u0aaf" },
             { "DatePatterns",
@@ -402,7 +415,6 @@ public class FormatData_gu extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
             { "calendarname.buddhist", "\u0aac\u0ac1\u0aa6\u0acd\u0aa7\u0abf\u0ab8\u0acd\u0a9f \u0a95\u0ac7\u0ab2\u0ac7\u0aa8\u0acd\u0aa1\u0ab0" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
