@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -154,10 +154,6 @@ public class FormatData_hy extends ListResourceBundle {
                "3-\u0580\u0564 \u0565\u057c\u0574\u057d.",
                "4-\u0580\u0564 \u0565\u057c\u0574\u057d.",
             };
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "\u053f\u0531",
-               "\u053f\u0540",
-            };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "\u0561",
                "\u0570",
@@ -190,25 +186,37 @@ public class FormatData_hy extends ListResourceBundle {
                "dd MMM, y \u0569. GGGG",
                "dd.MM.y G",
             };
+        final String[] metaValue_roc_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String metaValue_calendarname_gregorian = "\u0563\u0580\u056b\u0563\u0578\u0580\u0575\u0561\u0576 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u057f\u0561\u0580\u056b" },
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
+            { "TimePatterns", metaValue_TimePatterns },
+            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "field.zone", "\u056a\u0561\u0574\u0561\u0575\u056b\u0576 \u0563\u0578\u057f\u056b" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "\u0573\u0561\u057a\u0578\u0576\u0561\u056f\u0561\u0576 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581" },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "Eras", metaValue_Eras },
             { "japanese.MonthNames", metaValue_MonthNames },
+            { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "islamic.QuarterNames", metaValue_QuarterNames },
             { "long.Eras",
                 new String[] {
                     "\u0554\u0580\u056b\u057d\u057f\u0578\u057d\u056b\u0581 \u0561\u057c\u0561\u057b",
@@ -216,7 +224,9 @@ public class FormatData_hy extends ListResourceBundle {
                 }
             },
             { "islamic.DayNames", metaValue_DayNames },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "field.weekday", "\u0577\u0561\u0562\u0561\u0569\u057e\u0561 \u0585\u0580" },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
@@ -244,17 +254,26 @@ public class FormatData_hy extends ListResourceBundle {
             },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0580\u0578\u057a\u0565" },
             { "field.era", "\u0569\u057e\u0561\u0580\u056f\u0578\u0582\u0569\u0575\u0578\u0582\u0576" },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "field.dayperiod", "\u053f\u0531/\u053f\u0540" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "calendarname.roc", "\u0574\u056b\u0576\u0563\u0578\u0582\u0578 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.DayNames", metaValue_DayNames },
+            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNames", metaValue_DayNames },
             { "field.month", "\u0561\u0574\u056b\u057d" },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "field.second", "\u057e\u0561\u0575\u0580\u056f\u0575\u0561\u0576" },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "field.week", "\u0577\u0561\u0562\u0561\u0569" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
             { "NumberPatterns",
@@ -265,64 +284,12 @@ public class FormatData_hy extends ListResourceBundle {
                 }
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "calendarname.islamic", "\u056b\u057d\u056c\u0561\u0574\u0561\u056f\u0561\u0576 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581" },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "long.CompactNumberPatterns",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "0 \u0570\u0561\u0566\u0561\u0580",
-                    "00 \u0570\u0561\u0566\u0561\u0580",
-                    "000 \u0570\u0561\u0566\u0561\u0580",
-                    "0 \u0574\u056b\u056c\u056b\u0578\u0576",
-                    "00 \u0574\u056b\u056c\u056b\u0578\u0576",
-                    "000 \u0574\u056b\u056c\u056b\u0578\u0576",
-                    "0 \u0574\u056b\u056c\u056b\u0561\u0580\u0564",
-                    "00 \u0574\u056b\u056c\u056b\u0561\u0580\u0564",
-                    "000 \u0574\u056b\u056c\u056b\u0561\u0580\u0564",
-                    "0 \u057f\u0580\u056b\u056c\u056b\u0578\u0576",
-                    "00 \u057f\u0580\u056b\u056c\u056b\u0578\u0576",
-                    "000 \u057f\u0580\u056b\u056c\u056b\u0578\u0576",
-                }
-            },
-            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "\u056a\u0561\u0574\u0561\u0575\u056b\u0576 \u0563\u0578\u057f\u056b" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "Eras", metaValue_Eras },
-            { "roc.DayNames", metaValue_DayNames },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "field.weekday", "\u0577\u0561\u0562\u0561\u0569\u057e\u0561 \u0585\u0580" },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "field.week", "\u0577\u0561\u0562\u0561\u0569" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "calendarname.islamic", "\u056b\u057d\u056c\u0561\u0574\u0561\u056f\u0561\u0576 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581" },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -358,7 +325,10 @@ public class FormatData_hy extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u056a\u0561\u0574" },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "calendarname.buddhist", "\u0562\u0578\u0582\u0564\u0564\u0561\u0575\u0561\u056f\u0561\u0576 \u0585\u0580\u0561\u0581\u0578\u0582\u0575\u0581" },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.MonthNames",
                 new String[] {
                     "\u0570\u0578\u0582\u0576\u057e\u0561\u0580",
@@ -376,12 +346,34 @@ public class FormatData_hy extends ListResourceBundle {
                     "",
                 }
             },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0570\u0561\u0566\u0561\u0580",
+                    "00 \u0570\u0561\u0566\u0561\u0580",
+                    "000 \u0570\u0561\u0566\u0561\u0580",
+                    "0 \u0574\u056b\u056c\u056b\u0578\u0576",
+                    "00 \u0574\u056b\u056c\u056b\u0578\u0576",
+                    "000 \u0574\u056b\u056c\u056b\u0578\u0576",
+                    "0 \u0574\u056b\u056c\u056b\u0561\u0580\u0564",
+                    "00 \u0574\u056b\u056c\u056b\u0561\u0580\u0564",
+                    "000 \u0574\u056b\u056c\u056b\u0561\u0580\u0564",
+                    "0 \u057f\u0580\u056b\u056c\u056b\u0578\u0576",
+                    "00 \u057f\u0580\u056b\u056c\u056b\u0578\u0576",
+                    "000 \u057f\u0580\u056b\u056c\u056b\u0578\u0576",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "standalone.QuarterNames", metaValue_QuarterNames },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
