@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -190,11 +190,27 @@ public class FormatData_lo extends ListResourceBundle {
                "d MMM y GGGG",
                "d/M/y G",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "\u0e84\u0ea3\u0eb4\u0e94\u0eaa\u0eb1\u0e81\u0e81\u0eb0\u0ea5\u0eb2\u0e94",
+               "\u0ea1\u0eb5\u0e88\u0eb5",
+               "\u0ec4\u0e95\u0ec2\u0e8a",
+               "\u0ec2\u0e8a\u0ea7\u0eb2",
+               "\u0eae\u0eb5\u0e8a\u0eb5",
+               "Reiwa",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "\u0e84.\u0eaa.",
+               "\u0ea1\u0eb5\u0e88\u0eb5",
+               "\u0ec4\u0e95\u0ec2\u0e8a",
+               "\u0ec2\u0e8a\u0ea7\u0eb2",
+               "\u0eae\u0eb5\u0e8a\u0eb5",
+               "Reiwa",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u0e81\u0ec8\u0ead\u0e99 R.O.C.",
                "",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "AH",
             };
@@ -219,7 +235,7 @@ public class FormatData_lo extends ListResourceBundle {
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "\u0ec0\u0ea7\u0ea5\u0eb2\u0ea1\u0eb2\u0e94\u0e95\u0eb0\u0e96\u0eb2\u0e99 {0}" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -227,6 +243,7 @@ public class FormatData_lo extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "\u0e81\u0ec8\u0ead\u0e99\u0e84\u0ea3\u0eb4\u0e94\u0eaa\u0eb1\u0e81\u0e81\u0eb0\u0ea5\u0eb2\u0e94",
@@ -263,17 +280,8 @@ public class FormatData_lo extends ListResourceBundle {
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0e99\u0eb2\u0e97\u0eb5" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "\u0eaa\u0eb0\u0ec4\u0edd" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "\u0e84\u0ea3\u0eb4\u0e94\u0eaa\u0eb1\u0e81\u0e81\u0eb0\u0ea5\u0eb2\u0e94",
-                    "\u0ea1\u0eb5\u0e88\u0eb5",
-                    "\u0ec4\u0e95\u0ec2\u0e8a",
-                    "\u0ec2\u0e8a\u0ea7\u0eb2",
-                    "\u0eae\u0eb5\u0e8a\u0eb5",
-                    "",
-                }
-            },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0e81\u0ec8\u0ead\u0e99\u0e97\u0ec8\u0ebd\u0e87/\u0eab\u0ebc\u0eb1\u0e87\u0e97\u0ec8\u0ebd\u0e87" },
             { "islamic.MonthNames",
@@ -303,9 +311,10 @@ public class FormatData_lo extends ListResourceBundle {
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u0ec0\u0e94\u0eb7\u0ead\u0e99" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u0ea7\u0eb4\u0e99\u0eb2\u0e97\u0eb5" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -318,10 +327,31 @@ public class FormatData_lo extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0e9b\u0eb0\u0e95\u0eb4\u0e97\u0eb4\u0e99\u0ead\u0eb4\u0eaa\u0eb0\u0ea5\u0eb2\u0ea1" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "\u0ec0\u0ea7\u0ea5\u0eb2 {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0e9e\u0eb1\u0e99",
+                    "00 \u0e9e\u0eb1\u0e99",
+                    "0 \u0ec1\u0eaa\u0e99",
+                    "0 \u0ea5\u0ec9\u0eb2\u0e99",
+                    "00 \u0ea5\u0ec9\u0eb2\u0e99",
+                    "000 \u0ea5\u0ec9\u0eb2\u0e99",
+                    "0 \u0e95\u0eb7\u0ec9",
+                    "00 \u0e95\u0eb7\u0ec9",
+                    "000 \u0e95\u0eb7\u0ec9",
+                    "0 \u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
+                    "00 \u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
+                    "000 \u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -332,9 +362,10 @@ public class FormatData_lo extends ListResourceBundle {
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u0ec0\u0e82\u0e94\u0ec0\u0ea7\u0ea5\u0eb2" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
@@ -344,13 +375,15 @@ public class FormatData_lo extends ListResourceBundle {
             { "field.weekday", "\u0ea1\u0eb7\u0ec9\u0e82\u0ead\u0e87\u0ead\u0eb2\u0e97\u0eb4\u0e94" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
             { "field.week", "\u0ead\u0eb2\u0e97\u0eb4\u0e94" },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -360,6 +393,25 @@ public class FormatData_lo extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u0e9e\u0eb1\u0e99",
+                    "00\u00a0\u0e9e\u0eb1\u0e99",
+                    "000\u00a0\u0e81\u0eb5\u0e9a",
+                    "0\u00a0\u0ea5\u0ec9\u0eb2\u0e99",
+                    "00\u00a0\u0ea5\u0ec9\u0eb2\u0e99",
+                    "000\u00a0\u0ea5\u0ec9\u0eb2\u0e99",
+                    "0\u00a0\u0e95\u0eb7\u0ec9",
+                    "00\u00a0\u0e95\u0eb7\u0ec9",
+                    "000\u00a0\u0e95\u0eb7\u0ec9",
+                    "0\u00a0\u0ea5\u0ec9\u0eb2\u0e99\u0ea5\u0ec9\u0eb2\u0e99",
+                    "00\u0ea5\u0ea5",
+                    "000\u0ea5\u0ea5",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "\u0ec0\u0ea7\u0ea5\u0eb2\u0e81\u0eb2\u0e87\u0ec0\u0ea7\u0eb1\u0e99 {0}" },
             { "DatePatterns",
@@ -392,24 +444,16 @@ public class FormatData_lo extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0e9b\u0eb0\u0e95\u0eb4\u0e97\u0eb4\u0e99 \u0e9e\u0eb8\u0e94\u0e97\u0eb0\u0eaa\u0eb1\u0e87\u0e81\u0eb2\u0e94" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.Eras",
-                new String[] {
-                    "\u0e84.\u0eaa.",
-                    "\u0ea1\u0eb5\u0e88\u0eb5",
-                    "\u0ec4\u0e95\u0ec2\u0e8a",
-                    "\u0ec2\u0e8a\u0ea7\u0eb2",
-                    "\u0eae\u0eb5\u0e8a\u0eb5",
-                    "",
-                }
-            },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
