@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -178,7 +178,11 @@ public class FormatData_lv extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "budistu \u0113ra",
+            };
+        final String[] metaValue_java_time_buddhist_Eras = new String[] {
                "BC",
                "B.E.",
             };
@@ -186,17 +190,29 @@ public class FormatData_lv extends ListResourceBundle {
                "EEEE, y. 'gada' d. MMMM G",
                "y. 'gada' d. MMMM G",
                "y. 'gada' d. MMM G",
-               "dd.MM.y GGGGG",
+               "dd.MM.y. GGGGG",
             };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
                "EEEE, y. 'gada' d. MMMM GGGG",
                "y. 'gada' d. MMMM GGGG",
                "y. 'gada' d. MMM GGGG",
-               "dd.MM.y G",
+               "dd.MM.y. G",
             };
-        final String[] metaValue_islamic_Eras = new String[] {
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "pirms \u0136\u012bnas Republikas dibin\u0101\u0161anas",
+               "Mi\u0146go",
+            };
+        final String[] metaValue_java_time_roc_Eras = new String[] {
+               "pirms republikas",
+               "Mi\u0146go",
+            };
+        final String[] metaValue_java_time_roc_narrow_Eras = new String[] {
+               "pirms rep.",
+               "Mi\u0146go",
+            };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
-               "AH",
+               "p\u0113c hid\u017eras",
             };
         final String metaValue_calendarname_gregorian = "Gregora kalend\u0101rs";
         final Object[][] data = new Object[][] {
@@ -204,7 +220,7 @@ public class FormatData_lv extends ListResourceBundle {
             { "field.year", "gads" },
             { "calendarname.islamic-umalqura", "isl\u0101ma kalend\u0101rs (Umm al-kura)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -214,12 +230,7 @@ public class FormatData_lv extends ListResourceBundle {
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "roc.long.Eras",
-                new String[] {
-                    "pirms \u0136\u012bnas Republikas dibin\u0101\u0161anas",
-                    "Mi\u0146go",
-                }
-            },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "timezone.regionFormat.standard", "{0}: standarta laiks" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -300,15 +311,9 @@ public class FormatData_lv extends ListResourceBundle {
             { "calendarname.roc", "\u0136\u012bnas Republikas kalend\u0101rs" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_Eras },
             { "field.month", "m\u0113nesis" },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "sekundes" },
-            { "roc.Eras",
-                new String[] {
-                    "pirms republikas",
-                    "Mi\u0146go",
-                }
-            },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
             { "NumberPatterns",
@@ -320,6 +325,8 @@ public class FormatData_lv extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "isl\u0101ma kalend\u0101rs" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -350,23 +357,15 @@ public class FormatData_lv extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras",
-                new String[] {
-                    "BC",
-                    "budistu \u0113ra",
-                }
-            },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "laika josla" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras",
-                new String[] {
-                    "pirms rep.",
-                    "Mi\u0146go",
-                }
-            },
+            { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
@@ -379,20 +378,16 @@ public class FormatData_lv extends ListResourceBundle {
             { "field.weekday", "ned\u0113\u013cas diena" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras",
-                new String[] {
-                    "",
-                    "p\u0113c hid\u017eras",
-                }
-            },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "ned\u0113\u013ca" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -421,6 +416,7 @@ public class FormatData_lv extends ListResourceBundle {
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "timezone.regionFormat.daylight", "{0}: vasaras laiks" },
             { "DatePatterns",
                 new String[] {
@@ -445,10 +441,10 @@ public class FormatData_lv extends ListResourceBundle {
                 }
             },
             { "field.hour", "stundas" },
-            { "islamic.narrow.Eras", metaValue_islamic_Eras },
             { "calendarname.buddhist", "budistu kalend\u0101rs" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
