@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -145,18 +145,24 @@ public class FormatData_ru extends ListResourceBundle {
                "3-\u0439 \u043a\u0432.",
                "4-\u0439 \u043a\u0432.",
             };
-        final String[] metaValue_TimePatterns = new String[] {
-               "H:mm:ss zzzz",
-               "H:mm:ss z",
-               "H:mm:ss",
-               "H:mm",
-            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "\u0431\u0443\u0434\u0434\u0438\u0439\u0441\u043a\u0430\u044f \u044d\u0440\u0430",
+            };
+        final String[] metaValue_java_time_buddhist_Eras = new String[] {
+               "BC",
+               "BE",
+            };
+        final String[] metaValue_java_time_buddhist_narrow_Eras = new String[] {
+               "BC",
+               "\u0431\u044d",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM y '\u0433'. G",
                "d MMMM y '\u0433'. G",
@@ -173,40 +179,57 @@ public class FormatData_ru extends ListResourceBundle {
                "AM",
                "PM",
             };
-        final String[] metaValue_islamic_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "\u043e\u0442 \u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u0430 \u0425\u0440\u0438\u0441\u0442\u043e\u0432\u0430",
+               "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
+               "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
+               "\u0421\u044c\u043e\u0432\u0430",
+               "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
+               "\u0420\u044d\u0439\u0432\u0430",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "\u043d. \u044d.",
+               "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
+               "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
+               "\u0421\u044c\u043e\u0432\u0430",
+               "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
+               "\u0420\u044d\u0439\u0432\u0430",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "\u0434\u043e \u043e\u0441\u043d\u043e\u0432\u0430\u043d\u0438\u044f \u041a\u0438\u0442\u0430\u0439\u0441\u043a\u043e\u0439 \u0440\u0435\u0441\u043f\u0443\u0431\u043b\u0438\u043a\u0438",
+               "\u041c\u0438\u043d\u044c\u0433\u043e",
+            };
+        final String[] metaValue_java_time_roc_Eras = new String[] {
+               "Before R.O.C.",
+               "Minguo",
+            };
+        final String[] metaValue_java_time_roc_narrow_Eras = new String[] {
+               "\u0434\u043e \u0440\u0435\u0441\u043f.",
+               "\u041c\u0438\u043d\u044c\u0433\u043e",
+            };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
-               "AH",
+               "\u043f\u043e\u0441\u043b\u0435 \u0445\u0438\u0434\u0436\u0440\u044b",
             };
         final String metaValue_calendarname_gregorian = "\u0433\u0440\u0438\u0433\u043e\u0440\u0438\u0430\u043d\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0433\u043e\u0434" },
             { "calendarname.islamic-umalqura", "\u0438\u0441\u043b\u0430\u043c\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c (\u0423\u043c\u043c \u0430\u043b\u044c-\u041a\u0443\u0440\u0430)" },
-            { "buddhist.narrow.Eras",
-                new String[] {
-                    "BC",
-                    "\u0431\u044d",
-                }
-            },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_narrow_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u0418\u0441\u043b\u0430\u043c\u0441\u043a\u0438\u0439 \u0433\u0440\u0430\u0436\u0434\u0430\u043d\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
             { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "\u0434\u043e \u043d.\u044d.",
                     "\u043d.\u044d.",
                 }
             },
-            { "roc.long.Eras",
-                new String[] {
-                    "\u0434\u043e \u043e\u0441\u043d\u043e\u0432\u0430\u043d\u0438\u044f \u041a\u0438\u0442\u0430\u0439\u0441\u043a\u043e\u0439 \u0440\u0435\u0441\u043f\u0443\u0431\u043b\u0438\u043a\u0438",
-                    "\u041c\u0438\u043d\u044c\u0433\u043e",
-                }
-            },
             { "timezone.regionFormat.standard", "{0}, \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043d\u043e\u0435 \u0432\u0440\u0435\u043c\u044f" },
             { "calendarname.japanese", "\u044f\u043f\u043e\u043d\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
             { "japanese.MonthNames", metaValue_MonthNames },
@@ -248,17 +271,8 @@ public class FormatData_ru extends ListResourceBundle {
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u043c\u0438\u043d\u0443\u0442\u0430" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "\u044d\u0440\u0430" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "\u043e\u0442 \u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u0430 \u0425\u0440\u0438\u0441\u0442\u043e\u0432\u0430",
-                    "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
-                    "\u0421\u044c\u043e\u0432\u0430",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
-                    "",
-                }
-            },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.MonthNames",
@@ -281,15 +295,10 @@ public class FormatData_ru extends ListResourceBundle {
             { "calendarname.roc", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c \u041c\u0438\u043d\u044c\u0433\u043e" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_Eras },
             { "field.month", "\u043c\u0435\u0441\u044f\u0446" },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434\u0430" },
-            { "roc.Eras",
-                new String[] {
-                    "Before R.O.C.",
-                    "Minguo",
-                }
-            },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayAbbreviations },
             { "NumberPatterns",
@@ -301,8 +310,9 @@ public class FormatData_ru extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
                 new String[] {
                     "\u044f\u043d\u0432.",
@@ -320,12 +330,32 @@ public class FormatData_ru extends ListResourceBundle {
                     "",
                 }
             },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0442\u044b\u0441\u044f\u0447\u0430",
+                    "00 \u0442\u044b\u0441\u044f\u0447\u0430",
+                    "000 \u0442\u044b\u0441\u044f\u0447\u0430",
+                    "0 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "00 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "000 \u043c\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "0 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
+                    "00 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
+                    "000 \u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434",
+                    "0 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "00 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
+                    "000 \u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "standalone.DayNarrows",
                 new String[] {
                     "\u0412",
@@ -337,23 +367,13 @@ public class FormatData_ru extends ListResourceBundle {
                     "\u0421",
                 }
             },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
-            { "buddhist.long.Eras",
-                new String[] {
-                    "BC",
-                    "\u0431\u0443\u0434\u0434\u0438\u0439\u0441\u043a\u0430\u044f \u044d\u0440\u0430",
-                }
-            },
-            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayAbbreviations },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "\u0447\u0430\u0441\u043e\u0432\u043e\u0439 \u043f\u043e\u044f\u0441" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras",
-                new String[] {
-                    "\u0434\u043e \u0440\u0435\u0441\u043f.",
-                    "\u041c\u0438\u043d\u044c\u0433\u043e",
-                }
-            },
+            { "roc.narrow.Eras", metaValue_java_time_roc_narrow_Eras },
             { "Eras",
                 new String[] {
                     "\u0434\u043e \u043d. \u044d.",
@@ -366,25 +386,17 @@ public class FormatData_ru extends ListResourceBundle {
             { "field.weekday", "\u0434\u0435\u043d\u044c \u043d\u0435\u0434\u0435\u043b\u0438" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras",
-                new String[] {
-                    "",
-                    "\u043f\u043e\u0441\u043b\u0435 \u0445\u0438\u0434\u0436\u0440\u044b",
-                }
-            },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras",
-                new String[] {
-                    "BC",
-                    "BE",
-                }
-            },
+            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "\u043d\u0435\u0434\u0435\u043b\u044f" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -393,7 +405,27 @@ public class FormatData_ru extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u0442\u044b\u0441'.'",
+                    "00\u00a0\u0442\u044b\u0441'.'",
+                    "000\u00a0\u0442\u044b\u0441'.'",
+                    "0\u00a0\u043c\u043b\u043d",
+                    "00\u00a0\u043c\u043b\u043d",
+                    "000\u00a0\u043c\u043b\u043d",
+                    "0\u00a0\u043c\u043b\u0440\u0434",
+                    "00\u00a0\u043c\u043b\u0440\u0434",
+                    "000\u00a0\u043c\u043b\u0440\u0434",
+                    "0\u00a0\u0442\u0440\u043b\u043d",
+                    "00\u00a0\u0442\u0440\u043b\u043d",
+                    "000\u00a0\u0442\u0440\u043b\u043d",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_narrow_Eras },
             { "timezone.regionFormat.daylight", "{0}, \u043b\u0435\u0442\u043d\u0435\u0435 \u0432\u0440\u0435\u043c\u044f" },
             { "DatePatterns",
                 new String[] {
@@ -404,7 +436,6 @@ public class FormatData_ru extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0447\u0430\u0441" },
@@ -425,7 +456,6 @@ public class FormatData_ru extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_Eras },
             { "calendarname.buddhist", "\u0431\u0443\u0434\u0434\u0438\u0439\u0441\u043a\u0438\u0439 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440\u044c" },
             { "standalone.MonthNames",
                 new String[] {
@@ -445,20 +475,11 @@ public class FormatData_ru extends ListResourceBundle {
                 }
             },
             { "buddhist.DayNarrows", metaValue_DayAbbreviations },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
             { "QuarterNames", metaValue_QuarterNames },
-            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.Eras",
-                new String[] {
-                    "\u043d. \u044d.",
-                    "\u042d\u043f\u043e\u0445\u0430 \u041c\u044d\u0439\u0434\u0437\u0438",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0422\u0430\u0439\u0441\u044c\u043e",
-                    "\u0421\u044c\u043e\u0432\u0430",
-                    "\u042d\u043f\u043e\u0445\u0430 \u0425\u044d\u0439\u0441\u044d\u0439",
-                    "",
-                }
-            },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
