@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -289,6 +289,25 @@ public class FormatData_si extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "{0} \u0dc0\u0dda\u0dbd\u0dcf\u0dc0" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "\u0daf\u0dc4\u0dc3 0",
+                    "\u0daf\u0dc4\u0dc3 00",
+                    "\u0daf\u0dc4\u0dc3 000",
+                    "\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1 0",
+                    "\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1 00",
+                    "\u0db8\u0dd2\u0dbd\u0dd2\u0dba\u0db1 000",
+                    "\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1 0",
+                    "\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1 00",
+                    "\u0db6\u0dd2\u0dbd\u0dd2\u0dba\u0db1 000",
+                    "\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1 0",
+                    "\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1 00",
+                    "\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dbd\u0dd2\u0dba\u0db1 000",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -327,6 +346,25 @@ public class FormatData_si extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "\u0daf0",
+                    "\u0daf00",
+                    "\u0daf000",
+                    "\u0db8\u0dd20",
+                    "\u0db8\u0dd200",
+                    "\u0db8\u0dd2000",
+                    "\u0db6\u0dd20",
+                    "\u0db6\u0dd200",
+                    "\u0db6\u0dd2000",
+                    "\u0da7\u0dca\u200d\u0dbb\u0dd20",
+                    "\u0da7\u0dca\u200d\u0dbb\u0dd200",
+                    "\u0da7\u0dca\u200d\u0dbb\u0dd2000",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} \u0daf\u0dd2\u0dc0\u0dcf\u0d86\u0dbd\u0ddd\u0d9a \u0dc0\u0dda\u0dbd\u0dcf\u0dc0" },
             { "DatePatterns",
