@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -134,13 +134,13 @@ public class FormatData_sq extends ListResourceBundle {
                "Sht",
             };
         final String[] metaValue_DayNarrows = new String[] {
-               "D",
-               "H",
-               "M",
-               "M",
-               "E",
-               "P",
-               "Sh",
+               "d",
+               "h",
+               "m",
+               "m",
+               "e",
+               "p",
+               "sh",
             };
         final String[] metaValue_QuarterNames = new String[] {
                "tremujori i par\u00eb",
@@ -158,6 +158,10 @@ public class FormatData_sq extends ListResourceBundle {
                "e paradites",
                "e pasdites",
             };
+        final String[] metaValue_narrow_AmPmMarkers = new String[] {
+               "p.d.",
+               "m.d.",
+            };
         final String[] metaValue_Eras = new String[] {
                "p.K.",
                "mb.K.",
@@ -205,15 +209,25 @@ public class FormatData_sq extends ListResourceBundle {
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Kalendari Islamik (tabelor, periudha civile)" },
-            { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "timezone.regionFormat.standard", "Ora standarde: {0}" },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "calendarname.japanese", "kalendar japonez" },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
+            { "standalone.DayAbbreviations",
+                new String[] {
+                    "die",
+                    "h\u00ebn",
+                    "mar",
+                    "m\u00ebr",
+                    "enj",
+                    "pre",
+                    "sht",
+                }
+            },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "long.Eras",
                 new String[] {
@@ -232,7 +246,7 @@ public class FormatData_sq extends ListResourceBundle {
                     "{1}, {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -255,24 +269,8 @@ public class FormatData_sq extends ListResourceBundle {
             { "field.era", "er\u00eb" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "paradite/pasdite" },
-            { "standalone.MonthNarrows",
-                new String[] {
-                    "J",
-                    "Sh",
-                    "M",
-                    "P",
-                    "M",
-                    "Q",
-                    "K",
-                    "G",
-                    "Sh",
-                    "T",
-                    "N",
-                    "Dh",
-                    "",
-                }
-            },
-            { "calendarname.roc", "kalendar minguoje (kinez)" },
+            { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "calendarname.roc", "kalendar minguo (i Republik\u00ebs s\u00eb Kin\u00ebs)" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "muaj" },
@@ -288,25 +286,9 @@ public class FormatData_sq extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "kalendar islamik" },
-            { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "standalone.MonthAbbreviations",
-                new String[] {
-                    "Jan",
-                    "Shk",
-                    "Mar",
-                    "Pri",
-                    "Maj",
-                    "Qer",
-                    "Korr",
-                    "Gush",
-                    "Sht",
-                    "Tet",
-                    "N\u00ebn",
-                    "Dhj",
-                    "",
-                }
-            },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Ora: {0}" },
             { "long.CompactNumberPatterns",
                 new String[] {
@@ -327,7 +309,7 @@ public class FormatData_sq extends ListResourceBundle {
                     "000 bilion",
                 }
             },
-            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames",
                 new String[] {
@@ -346,12 +328,12 @@ public class FormatData_sq extends ListResourceBundle {
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "brezi orar" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "dit\u00eb e jav\u00ebs" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -403,42 +385,16 @@ public class FormatData_sq extends ListResourceBundle {
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames",
-                new String[] {
-                    "E diel",
-                    "E h\u00ebn\u00eb",
-                    "E mart\u00eb",
-                    "E m\u00ebrkur\u00eb",
-                    "E enjte",
-                    "E premte",
-                    "E shtun\u00eb",
-                }
-            },
+            { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "or\u00eb" },
             { "calendarname.buddhist", "kalendar budist" },
-            { "standalone.MonthNames",
-                new String[] {
-                    "Janar",
-                    "Shkurt",
-                    "Mars",
-                    "Prill",
-                    "Maj",
-                    "Qershor",
-                    "Korrik",
-                    "Gusht",
-                    "Shtator",
-                    "Tetor",
-                    "N\u00ebntor",
-                    "Dhjetor",
-                    "",
-                }
-            },
+            { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
