@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -141,33 +141,55 @@ public class FormatData_th extends ListResourceBundle {
                "a",
                "p",
             };
+        final String[] metaValue_Eras = new String[] {
+               "\u0e01\u0e48\u0e2d\u0e19 \u0e04.\u0e28.",
+               "\u0e04.\u0e28.",
+            };
         final String[] metaValue_TimePatterns = new String[] {
                "H \u0e19\u0e32\u0e2c\u0e34\u0e01\u0e32 mm \u0e19\u0e32\u0e17\u0e35 ss \u0e27\u0e34\u0e19\u0e32\u0e17\u0e35 zzzz",
                "H \u0e19\u0e32\u0e2c\u0e34\u0e01\u0e32 mm \u0e19\u0e32\u0e17\u0e35 ss \u0e27\u0e34\u0e19\u0e32\u0e17\u0e35 z",
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_DateTimePatterns = new String[] {
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
-            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
+               "BC",
+               "\u0e1e\u0e38\u0e17\u0e18\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
+            };
+        final String[] metaValue_java_time_buddhist_Eras = new String[] {
                "BC",
                "\u0e1e.\u0e28.",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "\u0e04\u0e23\u0e34\u0e2a\u0e15\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
+               "\u0e40\u0e21\u0e08\u0e34",
+               "\u0e17\u0e30\u0e2d\u0e34\u0e42\u0e0a",
+               "\u0e42\u0e0a\u0e27\u0e30",
+               "\u0e40\u0e2e\u0e40\u0e0b",
+               "\u0e40\u0e23\u0e27\u0e30",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "\u0e04.\u0e28.",
+               "\u0e40\u0e21\u0e08\u0e34",
+               "\u0e17\u0e30\u0e2d\u0e34\u0e42\u0e0a",
+               "\u0e42\u0e0a\u0e27\u0e30",
+               "\u0e40\u0e2e\u0e40\u0e0b",
+               "\u0e40\u0e23\u0e27\u0e30",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u0e1b\u0e35\u0e01\u0e48\u0e2d\u0e19\u0e44\u0e15\u0e49\u0e2b\u0e27\u0e31\u0e19",
                "\u0e44\u0e15\u0e49\u0e2b\u0e27\u0e31\u0e19",
             };
-        final String[] metaValue_islamic_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "\u0e2e\u0e34\u0e08\u0e40\u0e23\u0e32\u0e30\u0e2b\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
+            };
+        final String[] metaValue_java_time_islamic_Eras = new String[] {
                "",
                "\u0e2e.\u0e28.",
             };
@@ -177,7 +199,7 @@ public class FormatData_th extends ListResourceBundle {
             { "field.year", "\u0e1b\u0e35" },
             { "calendarname.islamic-umalqura", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e2d\u0e34\u0e2a\u0e25\u0e32\u0e21 (\u0e2d\u0e38\u0e21\u0e21\u0e4c\u0e2d\u0e31\u0e25\u0e01\u0e38\u0e23\u0e32)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -193,13 +215,8 @@ public class FormatData_th extends ListResourceBundle {
             { "calendarname.islamic-civil", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e2d\u0e34\u0e2a\u0e25\u0e32\u0e21\u0e0b\u0e35\u0e27\u0e34\u0e25" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
-            { "narrow.Eras",
-                new String[] {
-                    "\u0e01\u0e48\u0e2d\u0e19 \u0e04.\u0e28.",
-                    "\u0e04.\u0e28.",
-                }
-            },
+            { "narrow.Eras", metaValue_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "\u0e40\u0e27\u0e25\u0e32\u0e21\u0e32\u0e15\u0e23\u0e10\u0e32\u0e19{0}" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -207,16 +224,24 @@ public class FormatData_th extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "long.Eras",
                 new String[] {
-                    "\u0e1b\u0e35\u0e01\u0e48\u0e2d\u0e19\u0e04\u0e23\u0e34\u0e2a\u0e15\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
+                    "\u0e1b\u0e35\u0e01\u0e48\u0e2d\u0e19\u0e04\u0e23\u0e34\u0e2a\u0e15\u0e01\u0e32\u0e25",
                     "\u0e04\u0e23\u0e34\u0e2a\u0e15\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
                 }
             },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns", metaValue_DateTimePatterns },
+            { "DateTimePatterns",
+                new String[] {
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
             { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
@@ -244,17 +269,8 @@ public class FormatData_th extends ListResourceBundle {
             },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u0e19\u0e32\u0e17\u0e35" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "\u0e2a\u0e21\u0e31\u0e22" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "\u0e04\u0e23\u0e34\u0e2a\u0e15\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
-                    "\u0e40\u0e21\u0e08\u0e34",
-                    "\u0e17\u0e30\u0e2d\u0e34\u0e42\u0e0a",
-                    "\u0e42\u0e0a\u0e27\u0e30",
-                    "\u0e40\u0e2e\u0e40\u0e0b",
-                    "",
-                }
-            },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0e0a\u0e48\u0e27\u0e07\u0e27\u0e31\u0e19" },
             { "standalone.MonthNarrows", metaValue_MonthAbbreviations },
@@ -285,9 +301,10 @@ public class FormatData_th extends ListResourceBundle {
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterNames },
-            { "islamic.Eras", metaValue_islamic_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_Eras },
             { "field.month", "\u0e40\u0e14\u0e37\u0e2d\u0e19" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u0e27\u0e34\u0e19\u0e32\u0e17\u0e35" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -307,10 +324,31 @@ public class FormatData_th extends ListResourceBundle {
                 }
             },
             { "calendarname.islamic", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e2d\u0e34\u0e2a\u0e25\u0e32\u0e21" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "\u0e40\u0e27\u0e25\u0e32{0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0e1e\u0e31\u0e19",
+                    "0 \u0e2b\u0e21\u0e37\u0e48\u0e19",
+                    "0 \u0e41\u0e2a\u0e19",
+                    "0 \u0e25\u0e49\u0e32\u0e19",
+                    "00 \u0e25\u0e49\u0e32\u0e19",
+                    "000 \u0e25\u0e49\u0e32\u0e19",
+                    "0 \u0e1e\u0e31\u0e19\u0e25\u0e49\u0e32\u0e19",
+                    "0 \u0e2b\u0e21\u0e37\u0e48\u0e19\u0e25\u0e49\u0e32\u0e19",
+                    "0 \u0e41\u0e2a\u0e19\u0e25\u0e49\u0e32\u0e19",
+                    "0 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
+                    "00 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
+                    "000 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -318,26 +356,18 @@ public class FormatData_th extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterNames },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras",
-                new String[] {
-                    "BC",
-                    "\u0e1e\u0e38\u0e17\u0e18\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
-                }
-            },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u0e40\u0e02\u0e15\u0e40\u0e27\u0e25\u0e32" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterNames },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "Eras",
-                new String[] {
-                    "\u0e1b\u0e35\u0e01\u0e48\u0e2d\u0e19 \u0e04.\u0e28.",
-                    "\u0e04.\u0e28.",
-                }
-            },
+            { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -349,20 +379,18 @@ public class FormatData_th extends ListResourceBundle {
                     "d/M/y G",
                 }
             },
-            { "field.weekday", "\u0e27\u0e31\u0e19\u0e43\u0e19\u0e2a\u0e31\u0e1b\u0e14\u0e32\u0e2b\u0e4c" },
+            { "field.weekday", "\u0e27\u0e31\u0e19\u0e02\u0e2d\u0e07\u0e2a\u0e31\u0e1b\u0e14\u0e32\u0e2b\u0e4c" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras",
-                new String[] {
-                    "",
-                    "\u0e2e\u0e34\u0e08\u0e40\u0e23\u0e32\u0e30\u0e2b\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
-                }
-            },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterNames },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "buddhist.DatePatterns",
                 new String[] {
                     "EEEE\u0e17\u0e35\u0e48 d MMMM GGGG y",
@@ -372,7 +400,7 @@ public class FormatData_th extends ListResourceBundle {
                 }
             },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "\u0e2a\u0e31\u0e1b\u0e14\u0e32\u0e2b\u0e4c" },
             { "buddhist.MonthNarrows", metaValue_MonthAbbreviations },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -395,7 +423,27 @@ public class FormatData_th extends ListResourceBundle {
                     "d/M/y G",
                 }
             },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0K",
+                    "00K",
+                    "000K",
+                    "0M",
+                    "00M",
+                    "000M",
+                    "0B",
+                    "00B",
+                    "000B",
+                    "0T",
+                    "00T",
+                    "000T",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "timezone.regionFormat.daylight", "\u0e40\u0e27\u0e25\u0e32\u0e2d\u0e2d\u0e21\u0e41\u0e2a\u0e07{0}" },
             { "DatePatterns",
                 new String[] {
@@ -407,7 +455,6 @@ public class FormatData_th extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
-            { "japanese.DateTimePatterns", metaValue_DateTimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0e0a\u0e31\u0e48\u0e27\u0e42\u0e21\u0e07" },
@@ -428,24 +475,16 @@ public class FormatData_th extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e1e\u0e38\u0e17\u0e18" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterNames },
-            { "japanese.Eras",
-                new String[] {
-                    "\u0e04.\u0e28.",
-                    "\u0e40\u0e21\u0e08\u0e34",
-                    "\u0e17\u0e30\u0e2d\u0e34\u0e42\u0e0a",
-                    "\u0e42\u0e0a\u0e27\u0e30",
-                    "\u0e40\u0e2e\u0e40\u0e0b",
-                    "",
-                }
-            },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
