@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -497,6 +497,25 @@ public class FormatData_to extends ListResourceBundle {
             { "brah.NumberElements", metaValue_brah_NumberElements },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "Taimi {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 afe",
+                    "0 mano",
+                    "0 kilu",
+                    "0 miliona",
+                    "00 miliona",
+                    "000 miliona",
+                    "0 piliona",
+                    "00 piliona",
+                    "000 piliona",
+                    "0 tiliona",
+                    "00 tiliona",
+                    "000 tiliona",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "standalone.QuarterNames",
@@ -825,6 +844,25 @@ public class FormatData_to extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0a",
+                    "0m",
+                    "0k",
+                    "0M",
+                    "00M",
+                    "000M",
+                    "0P",
+                    "00P",
+                    "000P",
+                    "0T",
+                    "00T",
+                    "000T",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} Taimi liliu" },
             { "DatePatterns",
