@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -253,7 +253,8 @@ public class CurrencyNames_dsb extends OpenListResourceBundle {
             { "usd", "ameriski dolar" },
             { "uyu", "uruguayski peso" },
             { "uzs", "usbekiski sum" },
-            { "vef", "venezuelski bol\u00edvar" },
+            { "vef", "venezuelski bol\u00edvar (2008\u20132018)" },
+            { "ves", "venezuelski bol\u00edvar" },
             { "vnd", "vietnamski dong" },
             { "vuv", "vanuatski vatu" },
             { "wst", "samoaska tala" },
