@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -72,14 +72,8 @@ public class CurrencyNames_yue extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "ADP", "ADP" },
-            { "AED", "AED" },
             { "AFA", "AFA" },
-            { "AFN", "AFN" },
             { "ALK", "ALK" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
             { "AOK", "AOK" },
             { "AON", "AON" },
             { "AOR", "AOR" },
@@ -87,29 +81,17 @@ public class CurrencyNames_yue extends OpenListResourceBundle {
             { "ARL", "ARL" },
             { "ARM", "ARM" },
             { "ARP", "ARP" },
-            { "ARS", "ARS" },
             { "ATS", "ATS" },
             { "AUD", "AU$" },
-            { "AWG", "AWG" },
             { "AZM", "AZM" },
-            { "AZN", "AZN" },
             { "BAD", "BAD" },
-            { "BAM", "BAM" },
             { "BAN", "BAN" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
             { "BEC", "BEC" },
             { "BEF", "BEF" },
             { "BEL", "BEL" },
             { "BGL", "BGL" },
             { "BGM", "BGM" },
-            { "BGN", "BGN" },
             { "BGO", "BGO" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
             { "BOL", "BOL" },
             { "BOP", "BOP" },
             { "BOV", "BOV" },
@@ -119,98 +101,45 @@ public class CurrencyNames_yue extends OpenListResourceBundle {
             { "BRN", "BRN" },
             { "BRR", "BRR" },
             { "BRZ", "BRZ" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
             { "BUK", "BUK" },
-            { "BWP", "BWP" },
             { "BYB", "BYB" },
             { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
             { "CHE", "CHE" },
-            { "CHF", "CHF" },
             { "CHW", "CHW" },
             { "CLE", "CLE" },
             { "CLF", "CLF" },
-            { "CLP", "CLP" },
-            { "CNH", "CNH" },
             { "CNX", "CNX" },
-            { "COP", "COP" },
             { "COU", "COU" },
-            { "CRC", "CRC" },
             { "CSD", "CSD" },
             { "CSK", "CSK" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
             { "CYP", "CYP" },
-            { "CZK", "CZK" },
             { "DDM", "DDM" },
             { "DEM", "DEM" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
             { "ECS", "ECS" },
             { "ECV", "ECV" },
             { "EEK", "EEK" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
             { "ESA", "ESA" },
             { "ESB", "ESB" },
             { "ESP", "ESP" },
-            { "ETB", "ETB" },
             { "FIM", "FIM" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
             { "FRF", "FRF" },
             { "GEK", "GEK" },
-            { "GEL", "GEL" },
             { "GHC", "GHC" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
             { "GNS", "GNS" },
             { "GQE", "GQE" },
             { "GRD", "GRD" },
-            { "GTQ", "GTQ" },
             { "GWE", "GWE" },
             { "GWP", "GWP" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
             { "HRD", "HRD" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
             { "IEP", "IEP" },
             { "ILP", "ILP" },
             { "ILR", "ILR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
             { "ISJ", "ISJ" },
-            { "ISK", "ISK" },
             { "ITL", "ITL" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
             { "JPY", "\u00a5" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
             { "KRH", "KRH" },
             { "KRO", "KRO" },
             { "KRW", "\uffe6" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
             { "LSL", "LSL" },
             { "LTL", "LTL" },
             { "LTT", "LTT" },
@@ -219,108 +148,47 @@ public class CurrencyNames_yue extends OpenListResourceBundle {
             { "LUL", "LUL" },
             { "LVL", "LVL" },
             { "LVR", "LVR" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
             { "MAF", "MAF" },
             { "MCF", "MCF" },
             { "MDC", "MDC" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
             { "MGF", "MGF" },
-            { "MKD", "MKD" },
             { "MKN", "MKN" },
             { "MLF", "MLF" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
             { "MTL", "MTL" },
             { "MTP", "MTP" },
-            { "MUR", "MUR" },
             { "MVP", "MVP" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
             { "MXP", "MXP" },
             { "MXV", "MXV" },
-            { "MYR", "MYR" },
             { "MZE", "MZE" },
             { "MZM", "MZM" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
             { "NIC", "NIC" },
-            { "NIO", "NIO" },
             { "NLG", "NLG" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
             { "PEI", "PEI" },
-            { "PEN", "PEN" },
             { "PES", "PES" },
-            { "PGK", "PGK" },
-            { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
             { "PLZ", "PLZ" },
             { "PTE", "PTE" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
             { "RHD", "RHD" },
             { "ROL", "ROL" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
             { "RUR", "RUR" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
             { "SDD", "SDD" },
-            { "SDG", "SDG" },
             { "SDP", "SDP" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
             { "SIT", "SIT" },
             { "SKK", "SKK" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
             { "SRG", "SRG" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
             { "SUR", "SUR" },
             { "SVC", "SVC" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
             { "TJR", "TJR" },
-            { "TJS", "TJS" },
             { "TMM", "TMM" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
             { "TPE", "TPE" },
             { "TRL", "TRL" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
             { "UAK", "UAK" },
             { "UGS", "UGS" },
-            { "UGX", "UGX" },
             { "USN", "USN" },
             { "USS", "USS" },
             { "UYI", "UYI" },
             { "UYP", "UYP" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
             { "VEB", "VEB" },
-            { "VEF", "VEF" },
             { "VNN", "VNN" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
             { "XAG", "XAG" },
             { "XAU", "XAU" },
             { "XBA", "XBA" },
@@ -339,15 +207,12 @@ public class CurrencyNames_yue extends OpenListResourceBundle {
             { "XUA", "XUA" },
             { "XXX", "XXX" },
             { "YDD", "YDD" },
-            { "YER", "YER" },
             { "YUD", "YUD" },
             { "YUM", "YUM" },
             { "YUN", "YUN" },
             { "YUR", "YUR" },
             { "ZAL", "ZAL" },
-            { "ZAR", "ZAR" },
             { "ZMK", "ZMK" },
-            { "ZMW", "ZMW" },
             { "ZRN", "ZRN" },
             { "ZRZ", "ZRZ" },
             { "ZWD", "ZWD" },
@@ -612,7 +477,8 @@ public class CurrencyNames_yue extends OpenListResourceBundle {
             { "uyu", "\u70cf\u62c9\u572d\u62ab\u7d22" },
             { "uzs", "\u70cf\u8332\u5225\u514b\u7d22\u59c6" },
             { "veb", "\u59d4\u5167\u745e\u62c9\u73bb\u5229\u74e6 (1871\u20132008)" },
-            { "vef", "\u59d4\u5167\u745e\u62c9\u73bb\u5229\u74e6" },
+            { "vef", "\u59d4\u5167\u745e\u62c9\u73bb\u5229\u74e6 (VEF)" },
+            { "ves", "\u59d4\u5167\u745e\u62c9\u73bb\u5229\u74e6" },
             { "vnd", "\u8d8a\u5357\u76fe" },
             { "vnn", "\u8d8a\u5357\u76fe (1978\u20131985)" },
             { "vuv", "\u842c\u90a3\u675c\u74e6\u5716" },
