@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -74,13 +74,11 @@ public class LocaleNames_gl extends OpenListResourceBundle {
         final String metaValue_bn = "bengal\u00ed";
         final String metaValue_bo = "tibetano";
         final String metaValue_el = "grego";
-        final String metaValue_gu = "guxarat\u00ed";
         final String metaValue_he = "hebreo";
         final String metaValue_hy = "armenio";
         final String metaValue_ja = "xapon\u00e9s";
         final String metaValue_ka = "xeorxiano";
         final String metaValue_km = "khmer";
-        final String metaValue_kn = "canar\u00e9s";
         final String metaValue_ko = "coreano";
         final String metaValue_lo = "laosiano";
         final String metaValue_ml = "malabar";
@@ -103,24 +101,24 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "rar", "rarotongano" },
             { "tet", "tetun" },
             { "AD", "Andorra" },
-            { "AE", "Emiratos \u00c1rabes Unidos" },
+            { "AE", "Os Emiratos \u00c1rabes Unidos" },
             { "nl_BE", "flamengo" },
             { "AF", "Afganist\u00e1n" },
-            { "AG", "Antiga e Barbuda" },
+            { "AG", "Antigua e Barbuda" },
             { "type.ca.ethiopic", "calendario et\u00edope" },
             { "AI", "Anguila" },
             { "key.tz", "Fuso horario" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "AO", "Angola" },
-            { "AQ", "Ant\u00e1rtida" },
-            { "AR", "Arxentina" },
+            { "AQ", "A Ant\u00e1rtida" },
+            { "AR", "A Arxentina" },
             { "AS", "Samoa Americana" },
             { "AT", "Austria" },
             { "AU", "Australia" },
             { "AW", "Aruba" },
             { "en_US", "ingl\u00e9s estadounidense" },
-            { "AX", "Illas Aland" },
+            { "AX", "Illas \u00c5land" },
             { "AZ", "Acerbaix\u00e1n" },
             { "BA", "Bosnia e Hercegovina" },
             { "BB", "Barbados" },
@@ -132,24 +130,24 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "BG", "Bulgaria" },
             { "BH", "Bahrain" },
             { "BI", "Burundi" },
-            { "BJ", "Benin" },
-            { "BL", "Saint-Barth\u00e9lemy" },
-            { "BM", "Bermudas" },
+            { "BJ", "Ben\u00edn" },
+            { "BL", "Saint Barth\u00e9lemy" },
+            { "BM", "Illas Bermudas" },
             { "myv", "erzya" },
             { "BN", "Brunei" },
             { "BO", "Bolivia" },
             { "BQ", "Caribe Neerland\u00e9s" },
-            { "BR", "Brasil" },
+            { "BR", "O Brasil" },
             { "BS", "Bahamas" },
             { "xog", "soga" },
             { "BT", "But\u00e1n" },
             { "BV", "Illa Bouvet" },
             { "BW", "Botswana" },
-            { "BY", "Bielorrusia" },
+            { "BY", "Belar\u00fas" },
             { "BZ", "Belize" },
             { "type.ca.persian", "calendario persa" },
             { "type.nu.hebr", "numeraci\u00f3n hebrea" },
-            { "CA", "Canad\u00e1" },
+            { "CA", "O Canad\u00e1" },
             { "CC", "Illas Cocos (Keeling)" },
             { "mzn", "mazandaran\u00ed" },
             { "CD", "Rep\u00fablica Democr\u00e1tica do Congo" },
@@ -160,14 +158,14 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "CK", "Illas Cook" },
             { "CL", "Chile" },
             { "CM", "Camer\u00fan" },
-            { "CN", "China" },
+            { "CN", "A China" },
             { "CO", "Colombia" },
             { "CP", "Illa Clipperton" },
             { "CR", "Costa Rica" },
             { "CU", "Cuba" },
             { "CV", "Cabo Verde" },
             { "CW", "Cura\u00e7ao" },
-            { "CX", "Illa de Nadal" },
+            { "CX", "Illa Christmas" },
             { "CY", "Chipre" },
             { "CZ", "Chequia" },
             { "eka", "ekajuk" },
@@ -196,9 +194,9 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "ada", "adangme" },
             { "EE", "Estonia" },
             { "EG", "Exipto" },
-            { "EH", "S\u00e1hara Occidental" },
+            { "EH", "O S\u00e1hara Occidental" },
             { "pau", "palauano" },
-            { "chk", "chuukese" },
+            { "chk", "chuuk" },
             { "chm", "mari" },
             { "cho", "choctaw" },
             { "chr", "cherokee" },
@@ -212,7 +210,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.nu.gujr", "d\u00edxitos guxarat\u00eds" },
             { "ady", "adigueo" },
             { "FI", "Finlandia" },
-            { "FJ", "Fidxi" },
+            { "FJ", "Fixi" },
             { "FK", "Illas Malvinas" },
             { "FM", "Micronesia" },
             { "key.va", "Variante local" },
@@ -223,7 +221,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.ca.indian", "Calendario nacional indio" },
             { "grc", "grego antigo" },
             { "GA", "Gab\u00f3n" },
-            { "GB", "Reino Unido" },
+            { "GB", "O Reino Unido" },
             { "pcm", "pidgin nixeriano" },
             { "GD", "Granada" },
             { "GE", "Xeorxia" },
@@ -240,7 +238,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "GS", "Illas Xeorxia do Sur e Sandwich do Sur" },
             { "GT", "Guatemala" },
             { "GU", "Guam" },
-            { "GW", "Guinea-Bissau" },
+            { "GW", "A Guinea Bissau" },
             { "tlh", "klingon" },
             { "GY", "G\u00fciana" },
             { "ckb", "kurdo soran\u00ed" },
@@ -262,7 +260,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "zza", "zazaki" },
             { "IL", "Israel" },
             { "IM", "Illa de Man" },
-            { "IN", "India" },
+            { "IN", "A India" },
             { "IO", "Territorio Brit\u00e1nico do Oc\u00e9ano \u00cdndico" },
             { "IQ", "Iraq" },
             { "IR", "Ir\u00e1n" },
@@ -276,7 +274,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "Beng", metaValue_bn },
             { "JM", "Xamaica" },
             { "JO", "Xordania" },
-            { "JP", "Xap\u00f3n" },
+            { "JP", "O Xap\u00f3n" },
             { "ain", "ainu" },
             { "guz", "gusii" },
             { "type.nu.knda", "d\u00edxitos canareses" },
@@ -286,11 +284,11 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "KE", "Kenya" },
             { "419", "Am\u00e9rica Latina" },
             { "KG", "Kirguizist\u00e1n" },
-            { "KH", "Cambodja" },
+            { "KH", "Camboxa" },
             { "KI", "Kiribati" },
             { "KM", "Comores" },
-            { "Knda", metaValue_kn },
             { "KN", "Saint Kitts e Nevis" },
+            { "Knda", "canar\u00e9s" },
             { "fr_CA", "franc\u00e9s canadense" },
             { "KP", "Corea do Norte" },
             { "KR", "Corea do Sur" },
@@ -301,14 +299,14 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "KZ", "Casaquist\u00e1n" },
             { "Cyrl", "cir\u00edlico" },
             { "LA", "Laos" },
-            { "LB", "L\u00edbano" },
+            { "LB", "O L\u00edbano" },
             { "LC", "Santa Luc\u00eda" },
             { "gwi", "gwich\u02bcin" },
             { "nds", "baixo alem\u00e1n" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
             { "LR", "Liberia" },
-            { "LS", "Lesoto" },
+            { "LS", "Lesotho" },
             { "LT", "Lituania" },
             { "LU", "Luxemburgo" },
             { "LV", "Letonia" },
@@ -322,13 +320,13 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "MC", "M\u00f3naco" },
             { "MD", "Moldavia" },
             { "ME", "Montenegro" },
-            { "MF", "Saint-Martin" },
+            { "MF", "Saint Martin" },
             { "MG", "Madagascar" },
             { "Thai", metaValue_th },
             { "MH", "Illas Marshall" },
             { "ale", "aleutiano" },
             { "type.nu.vaii", "D\u00edxitos Vai" },
-            { "MK", "Macedonia" },
+            { "MK", "Macedonia do Norte" },
             { "ML", "Mal\u00ed" },
             { "MM", "Myanmar (Birmania)" },
             { "MN", "Mongolia" },
@@ -371,14 +369,14 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "PA", "Panam\u00e1" },
             { "type.ca.islamic-civil", "Calendario isl\u00e1mico (civil, tabular)" },
             { "en_GB", "ingl\u00e9s brit\u00e1nico" },
-            { "PE", "Per\u00fa" },
-            { "PF", "Polinesia Francesa" },
+            { "PE", "O Per\u00fa" },
+            { "PF", "A Polinesia Francesa" },
             { "PG", "Pap\u00faa-Nova Guinea" },
             { "PH", "Filipinas" },
             { "PK", "Paquist\u00e1n" },
             { "PL", "Polonia" },
             { "ewo", "ewondo" },
-            { "PM", "Saint-Pierre-et-Miquelon" },
+            { "PM", "Saint Pierre et Miquelon" },
             { "PN", "Illas Pitcairn" },
             { "PR", "Porto Rico" },
             { "PS", "Territorios Palestinos" },
@@ -386,14 +384,14 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "PW", "Palau" },
             { "nia", "nias" },
             { "type.nu.greklow", "numeraci\u00f3n grega en min\u00fascula" },
-            { "PY", "Paraguai" },
+            { "PY", "O Paraguai" },
             { "tum", "tumbuka" },
             { "Hebr", metaValue_he },
             { "QA", "Qatar" },
             { "niu", "niueano" },
             { "QO", "Territorios afastados de Ocean\u00eda" },
             { "lez", "lezguio" },
-            { "tvl", "tuvaluano" },
+            { "tvl", "tuval\u00e9s" },
             { "001", "Mundo" },
             { "002", "\u00c1frica" },
             { "003", "Norteam\u00e9rica" },
@@ -410,7 +408,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "twq", "tasawaq" },
             { "011", "\u00c1frica Occidental" },
             { "SC", "Seychelles" },
-            { "SD", "Sud\u00e1n" },
+            { "SD", "O Sud\u00e1n" },
             { "013", "Am\u00e9rica Central" },
             { "SE", "Suecia" },
             { "014", "\u00c1frica Oriental" },
@@ -433,12 +431,12 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "arp", "arapaho" },
             { "type.nu.taml", "numeraci\u00f3n t\u00e1mil tradicional" },
             { "SR", "Suriname" },
-            { "SS", "Sud\u00e1n do Sur" },
+            { "SS", "O Sud\u00e1n do Sur" },
             { "ST", "San Tom\u00e9 e Pr\u00edncipe" },
             { "SV", "O Salvador" },
             { "SX", "Sint Maarten" },
             { "SY", "Siria" },
-            { "SZ", "Swazilandia" },
+            { "SZ", "Suazilandia" },
             { "TA", "Trist\u00e1n da Cunha" },
             { "asa", "asu" },
             { "type.ms.ussystem", "sistema estadounidense de unidades" },
@@ -455,7 +453,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "TL", "Timor Leste" },
             { "ybb", "yemba" },
             { "type.co.searchjl", "Clasificar por consonante inicial hangul" },
-            { "TM", "Turcomenist\u00e1n" },
+            { "TM", "Turkmenist\u00e1n" },
             { "TN", "Tunisia" },
             { "TO", "Tonga" },
             { "TR", "Turqu\u00eda" },
@@ -477,12 +475,12 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.co.pinyin", "Orde de clasificaci\u00f3n pinyin" },
             { "039", "Europa Meridional" },
             { "Sinh", metaValue_si },
-            { "UM", "Illas Ultramarinas dos EUA" },
+            { "UM", "Illas Menores Distantes dos Estados Unidos" },
             { "UN", "Naci\u00f3ns Unidas" },
-            { "US", "Estados Unidos de Am\u00e9rica" },
+            { "US", "Os Estados Unidos" },
             { "haw", "hawaiano" },
             { "type.co.gb2312han", "orde de clasifcaci\u00f3n chinesa simplificada - GB2312" },
-            { "UY", "Uruguai" },
+            { "UY", "O Uruguai" },
             { "prg", "prusiano" },
             { "UZ", "Uzbequist\u00e1n" },
             { "tzm", "tamazight de Marrocos central" },
@@ -512,10 +510,10 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "awa", "awadhi" },
             { "061", "Polinesia" },
             { "XK", "Kosovo" },
-            { "Gujr", metaValue_gu },
+            { "Gujr", "guxarat\u00ed" },
             { "Zxxx", "non escrito" },
             { "wbp", "walrpiri" },
-            { "YE", "Iemen" },
+            { "YE", "O Iemen" },
             { "nqo", "n\u2019ko" },
             { "type.co.standard", "criterio de ordenaci\u00f3n est\u00e1ndar" },
             { "YT", "Mayotte" },
@@ -529,7 +527,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "ZZ", "Rexi\u00f3n desco\u00f1ecida" },
             { "type.ms.metric", "sistema m\u00e9trico decimal" },
             { "type.ca.iso8601", "calendario ISO-8601" },
-            { "nso", "sesotho sa leboa" },
+            { "nso", "sesotho do norte" },
             { "type.nu.telu", "d\u00edxitos de telugu" },
             { "loz", "lozi" },
             { "jmc", "machame" },
@@ -547,7 +545,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.ca.islamic-rgsa", "Calendario isl\u00e1mico (Arabia Saudita," },
             { "sad", "sandawe" },
             { "type.nu.roman", "numeraci\u00f3n romana" },
-            { "sah", "sakha" },
+            { "sah", "iacuto" },
             { "saq", "samburu" },
             { "sat", "santali" },
             { "type.d0.npinyin", "Num\u00e9rico" },
@@ -584,12 +582,12 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "sdh", "kurdo meridional" },
             { "ay", "aimar\u00e1" },
             { "az", "acerbaixano" },
-            { "ba", "baskir" },
+            { "ba", "baxkir" },
             { "type.co.unihan", "Criterio de ordenaci\u00f3n radical-trazo" },
             { "be", "bielorruso" },
             { "bg", "b\u00falgaro" },
             { "bi", "bislama" },
-            { "bm", "bambaro" },
+            { "bm", "bambara" },
             { "bn", metaValue_bn },
             { "bo", metaValue_bo },
             { "dgr", "dogrib" },
@@ -644,7 +642,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "Hant", "tradicional" },
             { "ff", "fula" },
             { "fi", "fin\u00e9s" },
-            { "fj", "fidxiano" },
+            { "fj", "fixiano" },
             { "fon", "fon" },
             { "bgn", "baluchi occidental" },
             { "yue", "canton\u00e9s" },
@@ -660,7 +658,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "bho", "bhojpuri" },
             { "und", "lingua desco\u00f1ecida" },
             { "type.ca.ethiopic-amete-alem", "Calendario Amete Alem et\u00edope" },
-            { "gu", metaValue_gu },
+            { "gu", "guxarati" },
             { "gv", "manx" },
             { "ha", "hausa" },
             { "he", metaValue_he },
@@ -676,7 +674,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "Jamo", "jamo" },
             { "id", "indonesio" },
             { "type.nu.tibt", "d\u00edxitos tibetanos" },
-            { "ig", "ibo" },
+            { "ig", "igbo" },
             { "ii", "yi sichuan\u00e9s" },
             { "io", "ido" },
             { "is", "island\u00e9s" },
@@ -702,10 +700,10 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "kk", "casaco" },
             { "kl", "groenland\u00e9s" },
             { "km", metaValue_km },
-            { "kn", metaValue_kn },
+            { "kn", "kannar\u00e1" },
             { "ko", metaValue_ko },
-            { "kr", "canuri" },
-            { "ks", "cachemir" },
+            { "kr", "kanuri" },
+            { "ks", "caxemir\u00e9s" },
             { "ku", "kurdo" },
             { "kv", "komi" },
             { "kw", "c\u00f3rnico" },
@@ -759,18 +757,18 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "mer", "meru" },
             { "type.nu.armn", "numeraci\u00f3n armenia" },
             { "om", "oromo" },
-            { "or", "oriya" },
+            { "or", "odi\u00e1" },
             { "os", "ossetio" },
             { "kbd", "cabardiano" },
             { "mfe", "crioulo mauriciano" },
             { "srn", "sranan tongo" },
-            { "pa", "panxabiano" },
+            { "pa", "panxab\u00ed" },
             { "dua", "duala" },
             { "pl", "polaco" },
             { "type.ca.dangi", "calendario dangi" },
             { "ps", "paxto" },
             { "pt", "portugu\u00e9s" },
-            { "key.co", "orde de clasificaci\u00f3n" },
+            { "key.co", "criterio de ordenaci\u00f3n" },
             { "pt_BR", "portugu\u00e9s do Brasil" },
             { "kcg", "tyap" },
             { "mgh", "makhuwa-meetto" },
@@ -795,7 +793,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.nu.orya", "d\u00edxitos do ori\u00e1" },
             { "type.nu.hanidec", "numeraci\u00f3n decimal chinesa" },
             { "ru", "ruso" },
-            { "rw", "ruand\u00e9s" },
+            { "rw", "ki\u00f1aruanda" },
             { "kea", "caboverdiano" },
             { "mic", "micmac" },
             { "suk", "sukuma" },
@@ -816,7 +814,7 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "type.nu.arab", "d\u00edxitos ar\u00e1bigo-\u00edndicos" },
             { "sq", "alban\u00e9s" },
             { "sr", "serbio" },
-            { "ss", "swazi" },
+            { "ss", "suazi" },
             { "type.cf.account", "formato de moeda contable" },
             { "st", "sesotho" },
             { "su", "sundan\u00e9s" },
@@ -884,14 +882,14 @@ public class LocaleNames_gl extends OpenListResourceBundle {
             { "Latn", "latino" },
             { "type.nu.hans", "numeraci\u00f3n chinesa simplificada" },
             { "type.nu.hant", "numeraci\u00f3n chinesa tradicional" },
-            { "xh", "xosa" },
+            { "xh", "xhosa" },
             { "type.nu.romanlow", "numeraci\u00f3n romana en min\u00fasculas" },
             { "byn", "blin" },
             { "moh", "mohawk" },
             { "kkj", "kako" },
             { "yi", "yiddish" },
             { "mos", "mossi" },
-            { "yo", "yoruba" },
+            { "yo", "ioruba" },
             { "type.nu.traditional", "Numeros tradicionais" },
             { "es_MX", "espa\u00f1ol de M\u00e9xico" },
             { "vai", "vai" },
