@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -135,7 +135,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "AF", "\u10d0\u10d5\u10e6\u10d0\u10dc\u10d4\u10d7\u10d8" },
             { "AG", "\u10d0\u10dc\u10e2\u10d8\u10d2\u10e3\u10d0 \u10d3\u10d0 \u10d1\u10d0\u10e0\u10d1\u10e3\u10d3\u10d0" },
             { "type.ca.ethiopic", "\u10d4\u10d7\u10d8\u10dd\u10de\u10d8\u10e3\u10e0\u10d8 \u10d9\u10d0\u10da\u10d4\u10dc\u10d3\u10d0\u10e0\u10d8" },
-            { "AI", "\u10d0\u10dc\u10d2\u10d5\u10d8\u10da\u10d0" },
+            { "AI", "\u10d0\u10dc\u10d2\u10d8\u10da\u10d8\u10d0" },
             { "AL", "\u10d0\u10da\u10d1\u10d0\u10dc\u10d4\u10d7\u10d8" },
             { "AM", "\u10e1\u10dd\u10db\u10ee\u10d4\u10d7\u10d8" },
             { "Teng", "\u10e2\u10d4\u10dc\u10d2\u10d5\u10d0\u10e0\u10d8" },
@@ -292,7 +292,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "Jurc", "\u10ef\u10e3\u10e0\u10ef\u10d4\u10dc\u10e3\u10da\u10d8" },
             { "de_AT", "\u10d0\u10d5\u10e1\u10e2\u10e0\u10d8\u10e3\u10da\u10d8 \u10d2\u10d4\u10e0\u10db\u10d0\u10dc\u10e3\u10da\u10d8" },
             { "Vaii", metaValue_vai },
-            { "HK", "\u10f0\u10dd\u10dc\u10d9\u10dd\u10dc\u10d2\u10d8\u10e1 \u10e1\u10de\u10d4\u10ea\u10d8\u10d0\u10da\u10e3\u10e0\u10d8 \u10d0\u10d3\u10db\u10d8\u10dc\u10d8\u10e1\u10e2\u10e0\u10d0\u10ea\u10d8\u10e3\u10da\u10d8 \u10e0\u10d4\u10d2\u10d8\u10dd\u10dc\u10d8 \u10e9\u10d8\u10dc\u10d4\u10d7\u10d8" },
+            { "HK", "\u10f0\u10dd\u10dc\u10d9\u10dd\u10dc\u10d2\u10d8\u10e1 \u10e1\u10de\u10d4\u10ea\u10d8\u10d0\u10da\u10e3\u10e0\u10d8 \u10d0\u10d3\u10db\u10d8\u10dc\u10d8\u10e1\u10e2\u10e0\u10d0\u10ea\u10d8\u10e3\u10da\u10d8 \u10e0\u10d4\u10d2\u10d8\u10dd\u10dc\u10d8, \u10e9\u10d8\u10dc\u10d4\u10d7\u10d8" },
             { "HM", "\u10f0\u10d4\u10e0\u10d3\u10d8 \u10d3\u10d0 \u10db\u10d0\u10d9\u10d3\u10dd\u10dc\u10d0\u10da\u10d3\u10d8\u10e1 \u10d9\u10e3\u10dc\u10eb\u10e3\u10da\u10d4\u10d1\u10d8" },
             { "HN", "\u10f0\u10dd\u10dc\u10d3\u10e3\u10e0\u10d0\u10e1\u10d8" },
             { "HR", "\u10ee\u10dd\u10e0\u10d5\u10d0\u10e2\u10d8\u10d0" },
@@ -365,7 +365,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "LR", "\u10da\u10d8\u10d1\u10d4\u10e0\u10d8\u10d0" },
             { "LS", "\u10da\u10d4\u10e1\u10dd\u10d7\u10dd" },
             { "Phlv", "\u10ec\u10d8\u10d2\u10dc\u10e3\u10e0\u10d8 \u10e4\u10d0\u10da\u10d0\u10e3\u10e0\u10d8" },
-            { "LT", "\u10da\u10d8\u10e2\u10d5\u10d0" },
+            { "LT", "\u10da\u10d8\u10d4\u10e2\u10e3\u10d5\u10d0" },
             { "LU", "\u10da\u10e3\u10e5\u10e1\u10d4\u10db\u10d1\u10e3\u10e0\u10d2\u10d8" },
             { "LV", "\u10da\u10d0\u10e2\u10d5\u10d8\u10d0" },
             { "Kana", "\u10d9\u10d0\u10e2\u10d0\u10d9\u10d0\u10dc\u10d0" },
@@ -392,7 +392,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "MM", "\u10db\u10d8\u10d0\u10dc\u10db\u10d0\u10e0\u10d8 (\u10d1\u10d8\u10e0\u10db\u10d0)" },
             { "MN", "\u10db\u10dd\u10dc\u10e6\u10dd\u10da\u10d4\u10d7\u10d8" },
             { "new", "\u10dc\u10d4\u10d5\u10d0\u10e0\u10d8" },
-            { "MO", "\u10db\u10d0\u10d9\u10d0\u10dd\u10e1 \u10e1\u10de\u10d4\u10ea\u10d8\u10d0\u10da\u10e3\u10e0\u10d8 \u10d0\u10d3\u10db\u10d8\u10dc\u10d8\u10e1\u10e2\u10e0\u10d0\u10ea\u10d8\u10e3\u10da\u10d8 \u10e0\u10d4\u10d2\u10d8\u10dd\u10dc\u10d8 \u10e9\u10d8\u10dc\u10d4\u10d7\u10d8" },
+            { "MO", "\u10db\u10d0\u10d9\u10d0\u10dd\u10e1 \u10e1\u10de\u10d4\u10ea\u10d8\u10d0\u10da\u10e3\u10e0\u10d8 \u10d0\u10d3\u10db\u10d8\u10dc\u10d8\u10e1\u10e2\u10e0\u10d0\u10ea\u10d8\u10e3\u10da\u10d8 \u10e0\u10d4\u10d2\u10d8\u10dd\u10dc\u10d8, \u10e9\u10d8\u10dc\u10d4\u10d7\u10d8" },
             { "MP", "\u10e9\u10e0\u10d3\u10d8\u10da\u10dd\u10d4\u10d7 \u10db\u10d0\u10e0\u10d8\u10d0\u10dc\u10d0\u10e1 \u10d9\u10e3\u10dc\u10eb\u10e3\u10da\u10d4\u10d1\u10d8" },
             { "MQ", "\u10db\u10d0\u10e0\u10e2\u10d8\u10dc\u10d8\u10d9\u10d0" },
             { "MR", "\u10db\u10d0\u10d5\u10e0\u10d8\u10e2\u10d0\u10dc\u10d8\u10d0" },
@@ -849,7 +849,7 @@ public class LocaleNames_ka extends OpenListResourceBundle {
             { "fur", "\u10e4\u10e0\u10d8\u10e3\u10da\u10e3\u10e0\u10d8" },
             { "lo", metaValue_lo },
             { "type.ms.uksystem", "\u10d1\u10e0\u10d8\u10e2\u10d0\u10dc\u10e3\u10da\u10d8 \u10e1\u10d0\u10d6\u10dd\u10db\u10d8 \u10e1\u10d8\u10e1\u10e2\u10d4\u10db\u10d0" },
-            { "lt", "\u10da\u10d8\u10e2\u10d5\u10e3\u10e0\u10d8" },
+            { "lt", "\u10da\u10d8\u10d4\u10e2\u10e3\u10d5\u10e3\u10e0\u10d8" },
             { "lu", "\u10da\u10e3\u10d1\u10d0-\u10d9\u10d0\u10e2\u10d0\u10dc\u10d2\u10d0" },
             { "lv", "\u10da\u10d0\u10e2\u10d5\u10d8\u10e3\u10e0\u10d8" },
             { "mg", "\u10db\u10d0\u10da\u10d0\u10d2\u10d0\u10e1\u10d8\u10e3\u10e0\u10d8" },
