@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -98,6 +98,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "AT", "\u0410\u0432\u0441\u0442\u0440\u0438\u044f" },
             { "AU", "\u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f" },
             { "AW", "\u0410\u0440\u0443\u0431\u0430" },
+            { "en_US", "\u0430\u043d\u0433\u043b\u0438\u0441\u0447\u0435 (\u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u041a\u043e\u0448\u043c\u043e \u0428\u0442\u0430\u0442\u0442\u0430\u0440\u044b)" },
             { "AX", "\u0410\u043b\u0430\u043d\u0434 \u0430\u0440\u0430\u043b\u0434\u0430\u0440\u044b" },
             { "AZ", "\u0410\u0437\u0435\u0440\u0431\u0430\u0439\u0436\u0430\u043d" },
             { "BA", "\u0411\u043e\u0441\u043d\u0438\u044f \u0436\u0430\u043d\u0430 \u0413\u0435\u0440\u0446\u0435\u0433\u043e\u0432\u0438\u043d\u0430" },
@@ -143,7 +144,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "CP", "\u041a\u043b\u0438\u043f\u043f\u0435\u0440\u0442\u043e\u043d \u0430\u0440\u0430\u043b\u044b" },
             { "CR", "\u041a\u043e\u0441\u0442\u0430-\u0420\u0438\u043a\u0430" },
             { "CU", "\u041a\u0443\u0431\u0430" },
-            { "CV", "\u041a\u0430\u043f\u0435 \u0412\u0435\u0440\u0434\u0435" },
+            { "CV", "\u041a\u0430\u0431\u043e-\u0412\u0435\u0440\u0434\u0435" },
             { "CW", "\u041a\u044e\u0440\u0430\u0441\u0430\u043e" },
             { "CX", "\u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u043e \u0430\u0440\u0430\u043b\u044b" },
             { "CY", "\u041a\u0438\u043f\u0440" },
@@ -297,7 +298,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "MH", "\u041c\u0430\u0440\u0448\u0430\u043b\u043b \u0430\u0440\u0430\u043b\u0434\u0430\u0440\u044b" },
             { "ale", "\u0430\u043b\u0435\u0443\u0442\u0447\u0430" },
             { "Thai", "\u0422\u0430\u0439" },
-            { "MK", "\u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0438\u044f" },
+            { "MK", "\u0422\u04af\u043d\u0434\u04af\u043a \u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0438\u044f" },
             { "ML", "\u041c\u0430\u043b\u0438" },
             { "MM", "\u041c\u044c\u044f\u043d\u043c\u0430 (\u0411\u0438\u0440\u043c\u0430)" },
             { "MN", "\u041c\u043e\u043d\u0433\u043e\u043b\u0438\u044f" },
@@ -317,8 +318,9 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "MY", "\u041c\u0430\u043b\u0430\u0439\u0437\u0438\u044f" },
             { "MZ", "\u041c\u043e\u0437\u0430\u043c\u0431\u0438\u043a" },
             { "NA", "\u041d\u0430\u043c\u0438\u0431\u0438\u044f" },
+            { "202", "\u0410\u0444\u0440\u0438\u043a\u0430 \u04e9\u043b\u043a\u04e9\u043b\u04e9\u0440\u04af" },
             { "type.ca.hebrew", "\u0418\u0432\u0440\u0438\u0442 \u0436\u044b\u043b\u043d\u0430\u0430\u043c\u0430\u0441\u044b" },
-            { "NC", "\u0416\u0430\u04ca\u044b \u041a\u0430\u043b\u0435\u0434\u043e\u043d\u0438\u044f" },
+            { "NC", "\u0416\u0430\u04a3\u044b \u041a\u0430\u043b\u0435\u0434\u043e\u043d\u0438\u044f" },
             { "NE", "\u041d\u0438\u0433\u0435\u0440" },
             { "NF", "\u041d\u043e\u0440\u0444\u043e\u043b\u043a \u0430\u0440\u0430\u043b\u044b" },
             { "NG", "\u041d\u0438\u0433\u0435\u0440\u0438\u044f" },
@@ -330,7 +332,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "NR", "\u041d\u0430\u0443\u0440\u0443" },
             { "NU", "\u041d\u0438\u0443\u044d" },
             { "rof", "\u0440\u043e\u043c\u0431\u043e\u0447\u043e" },
-            { "NZ", "\u0416\u0430\u04ca\u044b \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f" },
+            { "NZ", "\u0416\u0430\u04a3\u044b \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f" },
             { "OM", "\u041e\u043c\u0430\u043d" },
             { "anp", "\u0430\u043d\u0433\u0438\u043a\u0430\u0447\u0430" },
             { "crs", "\u0441\u0435\u0441\u0435\u043b\u0432\u0430 \u043a\u0440\u0435\u043e\u043b \u0444\u0440\u0430\u043d\u0446\u0443\u0437\u0447\u0430" },
@@ -338,7 +340,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "PE", "\u041f\u0435\u0440\u0443" },
             { "PF", "\u041f\u043e\u043b\u0438\u043d\u0435\u0437\u0438\u044f (\u0444\u0440\u0430\u043d\u0446\u0438\u044f\u043b\u044b\u043a)" },
             { "PG", "\u041f\u0430\u043f\u0443\u0430-\u0416\u0430\u04a3\u044b \u0413\u0432\u0438\u043d\u0435\u044f" },
-            { "PH", "\u0424\u0438\u043b\u043b\u0438\u043f\u0438\u043d" },
+            { "PH", "\u0424\u0438\u043b\u0438\u043f\u043f\u0438\u043d" },
             { "PK", "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d" },
             { "PL", "\u041f\u043e\u043b\u044c\u0448\u0430" },
             { "ewo", "\u044d\u0432\u043e\u043d\u0434\u043e\u0447\u043e" },
@@ -441,7 +443,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "Sinh", "\u0421\u0438\u043d\u0433\u0430\u043b\u0430" },
             { "UM", "\u0410\u041a\u0428\u043d\u044b\u043d \u0441\u044b\u0440\u0442\u043a\u044b \u0430\u0440\u0430\u043b\u0434\u0430\u0440\u044b" },
             { "UN", "\u0411\u0423" },
-            { "US", "\u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u041a\u043e\u0448\u043c\u043e \u0428\u0442\u0430\u0442\u0442\u0430\u0440\u044b" },
+            { "US", "\u041a\u043e\u0448\u043c\u043e \u0428\u0442\u0430\u0442\u0442\u0430\u0440" },
             { "haw", "\u0433\u0430\u0432\u0430\u0439\u0447\u0430" },
             { "UY", "\u0423\u0440\u0443\u0433\u0432\u0430\u0439" },
             { "prg", "\u043f\u0440\u0443\u0441\u0441\u0447\u0430" },
@@ -689,7 +691,7 @@ public class LocaleNames_ky extends OpenListResourceBundle {
             { "dsb", "\u0442\u04e9\u043c\u04e9\u043d\u043a\u04af \u0441\u043e\u0440\u0431\u0438\u0430\u043d\u0447\u0430" },
             { "na", "\u043d\u0430\u0443\u0440\u0443\u0447\u0430" },
             { "type.co.search", "\u0416\u0430\u043b\u043f\u044b \u0438\u0437\u0434\u04e9\u04e9" },
-            { "nb", "\u043d\u043e\u0440\u0432\u0435\u0436\u0447\u0435 (\u0411\u0443\u043a\u043c\u0430\u043b)" },
+            { "nb", "\u043d\u043e\u0440\u0432\u0435\u0436\u0447\u0435 (\u0431\u0443\u043a\u043c\u0430\u043b)" },
             { "nd", "\u0442\u04af\u043d\u0434\u04af\u043a \u043d\u0434\u044b\u0431\u0435\u043b\u0447\u0435" },
             { "ne", "\u043d\u0435\u043f\u0430\u043b\u0447\u0430" },
             { "ng", "\u043d\u0434\u043e\u043d\u0433\u0430\u0447\u0430" },
