@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -113,7 +113,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "tem", "\u091f\u093f\u092e\u094d\u0928\u0947" },
             { "teo", "\u091f\u0947\u0938\u094b" },
             { "rap", "\u0930\u093e\u092a\u093e\u0928\u0941\u0908" },
-            { "AC", "\u090f\u0938\u094d\u0915\u0947\u0928\u094d\u0938\u0928 \u091f\u093e\u092a\u0941" },
+            { "AC", "\u0905\u0938\u0947\u0928\u094d\u0938\u0928 \u091f\u093e\u092a\u0941" },
             { "rar", "\u0930\u093e\u0930\u094b\u091f\u094b\u0919\u094d\u0917\u093e\u0928" },
             { "tet", "\u091f\u0947\u091f\u0941\u092e" },
             { "AD", "\u0905\u0928\u094d\u0921\u094b\u0930\u094d\u0930\u093e" },
@@ -147,12 +147,12 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "kum", "\u0915\u0941\u092e\u093f\u0915" },
             { "BE", "\u092c\u0947\u0932\u094d\u091c\u093f\u092f\u092e" },
             { "gmh", "\u092e\u0927\u094d\u092f \u0909\u091a\u094d\u091a \u091c\u0930\u094d\u092e\u0928" },
-            { "BF", "\u092c\u0930\u094d\u0915\u093f\u0928\u093e \u092b\u093e\u0938\u094b" },
+            { "BF", "\u092c\u0941\u0930\u094d\u0915\u093f\u0928\u093e \u092b\u093e\u0938\u094b" },
             { "BG", "\u092c\u0941\u0932\u094d\u0917\u0947\u0930\u093f\u092f\u093e" },
             { "BH", "\u092c\u0939\u0930\u093e\u0907\u0928" },
             { "BI", "\u092c\u0941\u0930\u0942\u0923\u094d\u0921\u0940" },
             { "BJ", "\u092c\u0947\u0928\u093f\u0928" },
-            { "BL", "\u0938\u0947\u0928\u094d\u091f \u092c\u093e\u0930\u094d\u0925\u093e\u0932\u0947\u092e\u0940" },
+            { "BL", "\u0938\u0947\u0928\u094d\u091f \u092c\u093e\u0930\u094d\u0925\u0947\u0932\u0947\u092e\u0940" },
             { "BM", "\u092c\u0930\u094d\u092e\u0941\u0921\u093e" },
             { "kut", "\u0915\u0941\u0924\u0947\u0928\u093e\u0907" },
             { "myv", "\u0907\u0930\u094d\u091c\u094d\u092f\u093e" },
@@ -174,10 +174,10 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "CC", "\u0915\u094b\u0915\u094b\u0938 (\u0915\u093f\u0932\u093f\u0902\u0917) \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
             { "mzn", "\u092e\u091c\u093e\u0928\u0921\u0947\u0930\u093e\u0928\u0940" },
             { "CD", "\u0915\u0919\u094d\u0917\u094b - \u0915\u093f\u0928\u094d\u0936\u093e\u0938\u093e" },
-            { "CF", "\u0915\u0947\u0928\u094d\u0926\u094d\u0930\u0940\u092f \u0905\u092b\u094d\u0930\u093f\u0915\u0940 \u0917\u0923\u0924\u0928\u094d\u0924\u094d\u0930" },
+            { "CF", "\u092e\u0927\u094d\u092f \u0905\u092b\u094d\u0930\u093f\u0915\u0940 \u0917\u0923\u0924\u0928\u094d\u0924\u094d\u0930" },
             { "CG", "\u0915\u0919\u094d\u0917\u094b \u092c\u094d\u0930\u093e\u091c\u093e\u092d\u093f\u0932" },
             { "CH", "\u0938\u094d\u0935\u093f\u091c\u0930\u0932\u094d\u092f\u093e\u0923\u094d\u0921" },
-            { "CI", "\u0906\u0907\u092d\u094b\u0930\u0940 \u0915\u094b\u0938\u094d\u091f" },
+            { "CI", "\u0915\u094b\u091f \u0926\u093f\u092d\u094b\u0930" },
             { "CK", "\u0915\u0941\u0915 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
             { "CL", "\u091a\u093f\u0932\u0940" },
             { "Kthi", "\u0915\u094d\u0925\u0940" },
@@ -246,7 +246,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "type.nu.gujr", "\u0917\u0941\u091c\u0930\u093e\u0924\u0940 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
             { "Inds", "\u0907\u0928\u094d\u0926\u0941\u0938" },
             { "ady", "\u0905\u0926\u093f\u0918\u0947" },
-            { "FI", "\u092b\u093f\u0928\u094d\u0932\u094d\u092f\u093e\u0923\u094d\u0921" },
+            { "FI", "\u092b\u093f\u0928\u0932\u094d\u092f\u093e\u0923\u094d\u0921" },
             { "FJ", "\u092b\u093f\u091c\u0940" },
             { "FK", "\u092b\u0915\u0932\u094d\u092f\u093e\u0923\u094d\u0921 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
             { "FM", "\u092e\u093e\u0907\u0915\u094d\u0930\u094b\u0928\u0947\u0938\u093f\u092f\u093e" },
@@ -259,7 +259,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "type.ca.indian", "\u092d\u093e\u0930\u0924\u0940\u092f \u0930\u093e\u0937\u094d\u091f\u094d\u0930\u093f\u092f \u092a\u093e\u0924\u094d\u0930\u094b" },
             { "grc", "\u092a\u0941\u0930\u093e\u0924\u0928 \u0917\u094d\u0930\u093f\u0915" },
             { "GA", "\u0917\u093e\u0935\u094b\u0928" },
-            { "GB", "\u092c\u0947\u0932\u093e\u092f\u0924" },
+            { "GB", "\u0938\u0902\u092f\u0941\u0915\u094d\u0924 \u0905\u0927\u093f\u0930\u093e\u091c\u094d\u092f" },
             { "pcm", "\u0928\u093e\u0907\u091c\u0947\u0930\u093f\u092f\u093e\u0932\u0940 \u092a\u093f\u0921\u094d\u091c\u093f\u0928" },
             { "GD", "\u0917\u094d\u0930\u0947\u0928\u093e\u0921\u093e" },
             { "GE", "\u091c\u0930\u094d\u091c\u093f\u092f\u093e" },
@@ -275,7 +275,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "GN", "\u0917\u093f\u0928\u0940" },
             { "GP", "\u0917\u094d\u0935\u093e\u0921\u0947\u0932\u0941\u092a" },
             { "GQ", "\u092d\u0942-\u092e\u0927\u094d\u092f\u0940\u092f \u0917\u093f\u0928\u0940" },
-            { "GR", "\u0917\u094d\u0930\u093f\u0938" },
+            { "GR", "\u0917\u094d\u0930\u0940\u0938" },
             { "GS", "\u0926\u0915\u094d\u0937\u093f\u0923 \u091c\u0930\u094d\u091c\u093f\u092f\u093e \u0930 \u0926\u0915\u094d\u0937\u093f\u0923 \u0938\u094d\u092f\u093e\u0928\u094d\u0921\u0935\u0940\u091a \u091f\u093e\u092a\u0941\u0939\u0930\u0942" },
             { "GT", "\u0917\u094d\u0935\u093e\u091f\u0947\u092e\u093e\u0932\u093e" },
             { "GU", "\u0917\u0941\u0935\u093e\u092e" },
@@ -284,11 +284,11 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "tlh", "\u0915\u094d\u0932\u093f\u0919\u094d\u0917\u0928" },
             { "Talu", "\u0928\u094d\u092f\u0942 \u091f\u093e\u0907 \u0932\u0941\u0907" },
             { "GY", "\u0917\u0941\u092f\u093e\u0928\u093e" },
-            { "ckb", "\u0915\u0947\u0928\u094d\u0926\u094d\u0930\u0940\u092f \u0915\u0941\u0930\u094d\u0926\u0940" },
+            { "ckb", "\u092e\u0927\u094d\u092f\u0935\u0930\u094d\u0924\u0940 \u0915\u0941\u0930\u094d\u0926\u093f\u0938" },
             { "zxx", "\u092d\u093e\u0937\u093f\u0915 \u0938\u093e\u092e\u0917\u094d\u0930\u0940 \u091b\u0948\u0928" },
             { "de_AT", "\u0905\u0938\u094d\u091f\u094d\u0930\u093f\u090f\u0928 \u091c\u0930\u094d\u092e\u0928" },
             { "Vaii", metaValue_vai },
-            { "HK", "\u0939\u0919\u0915\u0919 \u091a\u093f\u0928\u093f\u092f\u093e\u0901 \u0938\u092e\u093e\u091c\u092c\u093e\u0926\u0940 \u0938\u094d\u0935\u093e\u092f\u0924\u094d\u0924 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
+            { "HK", "\u0939\u0919\u0915\u0919 \u091a\u093f\u0928\u093f\u092f\u093e\u0901 \u0935\u093f\u0936\u0947\u0937 \u092a\u094d\u0930\u0936\u093e\u0938\u0928\u093f\u0915 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
             { "HM", "\u0939\u0930\u094d\u0921 \u091f\u093e\u092a\u0941 \u0930 \u092e\u094d\u092f\u093e\u0915\u0921\u094b\u0928\u093e\u0932\u094d\u0921 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
             { "HN", "\u0939\u0928\u094d\u0921\u0941\u0930\u093e\u0938" },
             { "HR", "\u0915\u094d\u0930\u094b\u090f\u0936\u093f\u092f\u093e" },
@@ -319,7 +319,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "pfl", "\u092a\u093e\u0932\u093e\u091f\u093f\u0928 \u091c\u0930\u094d\u092e\u0928" },
             { "JE", "\u091c\u0930\u094d\u0938\u0940" },
             { "type.ca.islamic", "\u0907\u0938\u094d\u0932\u093e\u092e\u0940 \u092a\u093e\u0924\u094d\u0930\u094b" },
-            { "JM", "\u091c\u092e\u093e\u0907\u0915\u093e" },
+            { "JM", "\u091c\u092e\u0948\u0915\u093e" },
             { "Beng", "\u092c\u0919\u094d\u0917\u093e\u0932\u0940" },
             { "JO", "\u091c\u094b\u0930\u094d\u0921\u0928" },
             { "gur", "\u092b\u094d\u0930\u093e\u092b\u094d\u0930\u093e" },
@@ -357,7 +357,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "phn", "\u092b\u094b\u0928\u093f\u0938\u093f\u092f\u093e\u0932\u0940" },
             { "gwi", "\u0917\u0941\u0907\u091a\u093f\u0928" },
             { "nds", "\u0924\u0932\u094d\u0932\u094b \u091c\u0930\u094d\u092e\u0928" },
-            { "LI", "\u0932\u093f\u090f\u0916\u091f\u0947\u0928\u094d\u0938\u094d\u091f\u093e\u0907\u0928" },
+            { "LI", "\u0932\u093f\u0915\u091f\u0947\u0928\u094d\u0938\u091f\u093e\u0907\u0928" },
             { "LK", "\u0936\u094d\u0930\u0940\u0932\u0919\u094d\u0915\u093e" },
             { "akk", "\u0905\u0915\u094d\u0915\u093e\u0926\u093f\u092f\u093e\u0932\u0940" },
             { "cop", "\u0915\u094b\u092a\u094d\u091f\u093f\u0915" },
@@ -379,19 +379,19 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "MA", "\u092e\u094b\u0930\u094b\u0915\u094d\u0915\u094b" },
             { "MC", "\u092e\u094b\u0928\u093e\u0915\u094b" },
             { "MD", "\u092e\u093e\u0932\u094d\u0921\u094b\u092d\u093e" },
-            { "ME", "\u092e\u094b\u0928\u094d\u091f\u0947\u0928\u0947\u0917\u094d\u0930\u094b" },
+            { "ME", "\u092e\u094b\u0928\u094d\u091f\u0947\u0928\u093f\u0917\u094d\u0930\u094b" },
             { "MF", "\u0938\u0947\u0928\u094d\u091f \u092e\u093e\u0930\u094d\u091f\u093f\u0928" },
             { "lam", "\u0932\u093e\u092e\u094d\u092c\u093e" },
             { "MG", "\u092e\u093e\u0921\u093e\u0917\u093e\u0938\u094d\u0915\u0930" },
             { "Thai", metaValue_th },
             { "MH", "\u092e\u093e\u0930\u094d\u0936\u0932 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
             { "ale", "\u0905\u0932\u0947\u0909\u091f" },
-            { "MK", "\u092e\u094d\u092f\u093e\u0938\u0947\u0921\u094b\u0928\u093f\u092f\u093e" },
+            { "MK", "\u0909\u0924\u094d\u0924\u0930 \u092e\u094d\u092f\u093e\u0938\u0947\u0921\u094b\u0928\u093f\u092f\u093e" },
             { "ML", "\u092e\u093e\u0932\u0940" },
             { "MM", "\u092e\u094d\u092f\u093e\u0928\u094d\u092e\u093e\u0930 (\u092c\u0930\u094d\u092e\u093e)" },
             { "MN", "\u092e\u0919\u094d\u0917\u094b\u0932\u093f\u092f\u093e" },
             { "new", "\u0928\u0947\u0935\u093e\u0930\u0940" },
-            { "MO", "\u092e\u0915\u093e\u0909 \u091a\u093f\u0928\u093f\u092f\u093e\u0901 \u0938\u094d\u0935\u0936\u093e\u0938\u093f\u0924 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
+            { "MO", "(\u092e\u0915\u093e\u0909 \u091a\u093f\u0928\u093f\u092f\u093e\u0901 \u0935\u093f\u0936\u0947\u0937 \u092a\u094d\u0930\u0936\u093e\u0938\u0928\u093f\u0915 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
             { "aln", "\u0918\u0947\u0917 \u0905\u0932\u094d\u092c\u093e\u0928\u093f\u092f\u093e\u0932\u0940" },
             { "MP", "\u0909\u0924\u094d\u0924\u0930\u0940 \u092e\u093e\u0930\u093f\u0906\u0928\u093e \u091f\u093e\u092a\u0941" },
             { "MQ", "\u092e\u093e\u0930\u094d\u091f\u093f\u0928\u093f\u0915" },
@@ -399,7 +399,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "MS", "\u092e\u094b\u0928\u094d\u091f\u0938\u0947\u0930\u094d\u0930\u093e\u091f" },
             { "MT", "\u092e\u093e\u0932\u094d\u091f\u093e" },
             { "cps", "\u0915\u093e\u092a\u093f\u091c\u094d\u0928\u094b\u0928" },
-            { "MU", "\u092e\u093e\u0909\u0930\u093f\u091f\u0938" },
+            { "MU", "\u092e\u094c\u0930\u093f\u0938\u093f\u092f\u0938" },
             { "alt", "\u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u0906\u0932\u094d\u091f\u093e\u0907" },
             { "MV", "\u092e\u093e\u0932\u094d\u0926\u093f\u092d\u094d\u0938" },
             { "MW", "\u092e\u093e\u0932\u093e\u0935\u0940" },
@@ -515,7 +515,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "type.nu.taml", "\u092a\u0930\u092e\u094d\u092a\u0930\u093e\u0917\u0924 \u0924\u093e\u092e\u093f\u0932 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
             { "SR", "\u0938\u0941\u0930\u093f\u0928\u0947\u092e" },
             { "aro", "\u0905\u0930\u093e\u0913\u0928\u093e" },
-            { "SS", "\u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u0938\u0941\u0921\u093e\u0928" },
+            { "SS", "\u0926\u0915\u094d\u0937\u093f\u0923 \u0938\u0941\u0921\u093e\u0928" },
             { "ST", "\u0938\u093e\u0913 \u091f\u094b\u092e\u0947 \u0930 \u092a\u094d\u0930\u093f\u0928\u094d\u0938\u093f\u092a" },
             { "arq", "\u0905\u0932\u094d\u091c\u0947\u0930\u093f\u092f\u093e\u0932\u0940 \u0905\u0930\u092c\u0940" },
             { "SV", "\u090f\u0932\u094d \u0938\u093e\u0932\u094d\u092d\u093e\u0921\u094b\u0930" },
@@ -583,7 +583,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "pro", "\u092a\u0941\u0930\u093e\u0924\u0928 \u092a\u094d\u0930\u094b\u092d\u0947\u0928\u094d\u0915\u093e\u0932" },
             { "VC", "\u0938\u0947\u0928\u094d\u091f \u092d\u093f\u0928\u094d\u0938\u0947\u0928\u094d\u091f \u0930 \u0917\u094d\u0930\u0947\u0928\u093e\u0921\u093f\u0928\u094d\u0938" },
             { "VE", "\u092d\u0947\u0928\u0947\u091c\u0941\u090f\u0932\u093e" },
-            { "VG", "\u092c\u0947\u0932\u093e\u092f\u0924\u0940 \u092d\u0930\u094d\u091c\u093f\u0928 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
+            { "VG", "\u092c\u0947\u0932\u093e\u092f\u0924\u0940 \u092d\u0930\u094d\u091c\u093f\u0928 \u091f\u093e\u092a\u0941\u0939\u0930\u0942" },
             { "VI", "\u0938\u0902\u092f\u0941\u0915\u094d\u0924 \u0930\u093e\u091c\u094d\u092f \u092d\u0930\u094d\u091c\u093f\u0928 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
             { "VN", "\u092d\u093f\u090f\u0924\u0928\u093e\u092e" },
             { "VU", "\u092d\u093e\u0928\u0941\u0906\u0924\u0941" },
@@ -626,7 +626,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "type.nu.geor", "\u091c\u0930\u094d\u091c\u093f\u092f\u093e\u0932\u0940 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
             { "Hira", "\u0939\u093f\u0930\u093e\u0917\u0928\u093e" },
             { "ZM", "\u091c\u093e\u092e\u094d\u092c\u093f\u092f\u093e" },
-            { "ZW", "\u091c\u093f\u092e\u094d\u092c\u093e\u092c\u0947" },
+            { "ZW", "\u091c\u093f\u092e\u094d\u092c\u093e\u092c\u0935\u0947" },
             { "ZZ", "\u0905\u091c\u094d\u091e\u093e\u0924 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
             { "Runr", "\u0930\u0942\u0928\u093f\u0915" },
             { "type.ms.metric", "\u092e\u0947\u091f\u094d\u0930\u093f\u0915 \u092a\u094d\u0930\u0923\u093e\u0932\u0940" },
@@ -779,6 +779,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "Hant", metaValue_Hant },
             { "ff", "\u092b\u0941\u0932\u093e\u0939" },
             { "shu", "\u091a\u093e\u0921 \u0905\u0930\u092c\u0940" },
+            { "hsn", "\u091c\u093f\u092f\u093e\u0919 \u091a\u093f\u0928\u093f\u092f\u093e\u0901" },
             { "fi", "\u092b\u093f\u0928\u093f\u0938" },
             { "fj", "\u092b\u093f\u091c\u093f\u092f\u0928" },
             { "fon", "\u092b\u094b\u0928" },
