@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -99,6 +99,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
         final String metaValue_ban = "Balinees";
         final String metaValue_bax = "Bamoun";
         final String metaValue_bug = "Buginees";
+        final String metaValue_ccp = "Chakma";
         final String metaValue_chr = "Cherokee";
         final String metaValue_cop = "Koptisch";
         final String metaValue_got = "Gothisch";
@@ -111,6 +112,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
         final String metaValue_peo = "Oudperzisch";
         final String metaValue_phn = "Foenicisch";
         final String metaValue_saz = "Saurashtra";
+        final String metaValue_sog = "Sogdisch";
         final String metaValue_ssy = "Saho";
         final String metaValue_vai = "Vai";
         final String metaValue_zbl = "Blissymbolen";
@@ -128,10 +130,12 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "Gniva/Njiva-dialect" },
             { "xmf", "Mingreels" },
+            { "ccp", metaValue_ccp },
             { "egy", "Oudegyptisch" },
             { "raj", "Rajasthani" },
             { "Phag", "Phags-pa" },
             { "tem", "Timne" },
+            { "Medf", "Medefaidrin" },
             { "type.nu.sind", "Khudawadi cijfers" },
             { "teo", "Teso" },
             { "rap", "Rapanui" },
@@ -172,6 +176,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "kum", "Koemuks" },
             { "BE", "Belgi\u00eb" },
             { "gmh", "Middelhoogduits" },
+            { "Sogo", "Oud Sogdisch" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgarije" },
             { "BH", "Bahrein" },
@@ -194,6 +199,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "BZ", "Belize" },
             { "Visp", "Zichtbare spraak" },
             { "type.ca.persian", "Perzische kalender" },
+            { "%%CREISS", "Creiss" },
             { "type.nu.hebr", "Hebreeuwse cijfers" },
             { "CA", "Canada" },
             { "CC", "Cocoseilanden" },
@@ -219,10 +225,10 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.nu.bali", "Balinese cijfers" },
             { "CZ", "Tsjechi\u00eb" },
             { "eka", "Ekajuk" },
-            { "Ahom", "Ahom" },
             { "Pauc", "Pau Cin Hau" },
             { "vls", "West-Vlaams" },
             { "%%RIGIK", "Klassiek Volap\u00fck" },
+            { "Sogd", metaValue_sog },
             { "DE", "Duitsland" },
             { "goh", "Oudhoogduits" },
             { "ace", "Atjehs" },
@@ -333,6 +339,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "zxx", "geen lingu\u00efstische inhoud" },
             { "Jurc", "Jurchen" },
             { "tly", "Talysh" },
+            { "%%VIVARAUP", "Vivaraup" },
             { "pdt", "Plautdietsch" },
             { "Vaii", metaValue_vai },
             { "HK", "Hongkong SAR van China" },
@@ -426,6 +433,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "LK", "Sri Lanka" },
             { "akk", "Akkadisch" },
             { "cop", metaValue_cop },
+            { "Hmnp", "Nyiakeng Puachue Hmong" },
             { "LR", "Liberia" },
             { "esu", "Yupik" },
             { "LS", "Lesotho" },
@@ -456,7 +464,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "MH", "Marshalleilanden" },
             { "ale", "Aleoetisch" },
             { "type.nu.vaii", "Vai-cijfers" },
-            { "MK", "Macedoni\u00eb" },
+            { "MK", "Noord-Macedoni\u00eb" },
             { "type.nu.mathdbl", "wiskundige cijfers met dubbele lijn" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Birma)" },
@@ -481,6 +489,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "MZ", "Mozambique" },
             { "Phli", "Inscriptioneel Pahlavi" },
             { "NA", "Namibi\u00eb" },
+            { "%%ARANES", "Aranees" },
             { "202", "Sub-Saharaans Afrika" },
             { "type.ca.hebrew", "Hebreeuwse kalender" },
             { "type.co.dictionary", "Woordenboeksorteervolgorde" },
@@ -511,10 +520,12 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "Mero", "Mero\u00eftisch" },
             { "crh", "Krim-Tataars" },
             { "ang", "Oudengels" },
+            { "%%GRMISTR", "Grmistr" },
             { "OM", "Oman" },
             { "%%PETR1708", "Petr1708" },
             { "anp", "Angika" },
             { "crs", "Seychellencreools" },
+            { "type.nu.hmnp", "Nyiakeng Puachue Hmong cijfers" },
             { "Xpeo", metaValue_peo },
             { "type.nu.hmng", "Pahawh Hmong cijfers" },
             { "PA", "Panama" },
@@ -526,6 +537,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "PG", "Papoea-Nieuw-Guinea" },
             { "PH", "Filipijnen" },
             { "PK", "Pakistan" },
+            { "%%NICARD", "Nicard" },
             { "PL", "Polen" },
             { "ewo", "Ewondo" },
             { "PM", "Saint-Pierre en Miquelon" },
@@ -554,6 +566,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "tvl", "Tuvaluaans" },
             { "Tavt", "Tai Viet" },
             { "%%SOTAV", "Sotavento-dialectgroep van Kabuverdianu" },
+            { "Maka", "Makasar" },
             { "001", "wereld" },
             { "002", "Afrika" },
             { "njo", "Ao Naga" },
@@ -565,22 +578,14 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "pnt", "Pontisch" },
             { "Rjng", "Rejang" },
             { "009", "Oceani\u00eb" },
+            { "Elym", "Elymaisch" },
             { "%%SURSILV", "Sursilvan" },
             { "RO", "Roemeni\u00eb" },
-            { "Qaaw", "Qaaw" },
             { "RS", "Servi\u00eb" },
             { "Mroo", "Mro" },
-            { "Qaax", "Qaax" },
-            { "Qaau", "Qaau" },
             { "RU", "Rusland" },
-            { "Qaav", "Qaav" },
-            { "Qaas", "Qaas" },
             { "RW", "Rwanda" },
-            { "Qaat", "Qaat" },
-            { "Qaaq", "Qaaq" },
-            { "Qaar", "Qaar" },
             { "type.nu.talu", "nieuwe Tai Lue cijfers" },
-            { "Qaba", "Qaba" },
             { "%%METELKO", "Metelko-alfabet" },
             { "Mani", "Manicheaans" },
             { "Ugar", "Ugaritisch" },
@@ -588,56 +593,38 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "SA", "Saoedi-Arabi\u00eb" },
             { "pon", "Pohnpeiaans" },
             { "Mand", "Mandaeans" },
-            { "Qaay", "Qaay" },
             { "SB", "Salomonseilanden" },
             { "twq", "Tasawaq" },
-            { "Qaaz", "Qaaz" },
             { "011", "West-Afrika" },
             { "SC", "Seychellen" },
-            { "Qabh", "Qabh" },
             { "SD", "Soedan" },
-            { "Qabi", "Qabi" },
             { "013", "Midden-Amerika" },
             { "SE", "Zweden" },
-            { "Qabf", "Qabf" },
             { "014", "Oost-Afrika" },
             { "arc", "Aramees" },
             { "Loma", "Loma" },
-            { "Qabg", "Qabg" },
             { "015", "Noord-Afrika" },
             { "SG", "Singapore" },
-            { "Qabd", "Qabd" },
             { "SH", "Sint-Helena" },
-            { "Qabe", "Qabe" },
             { "type.lb.strict", "strikte stijl regelafbreking" },
             { "017", "Centraal-Afrika" },
             { "SI", "Sloveni\u00eb" },
-            { "Qabb", "Qabb" },
             { "type.nu.mymrtlng", "Myanmar Tai Laing cijfers" },
             { "018", "Zuidelijk Afrika" },
             { "SJ", "Spitsbergen en Jan Mayen" },
-            { "Qabc", "Qabc" },
             { "Bamu", metaValue_bax },
             { "019", "Amerika" },
             { "SK", "Slowakije" },
-            { "Qabp", "Qabp" },
             { "Wole", "Woleai" },
             { "SL", "Sierra Leone" },
-            { "Qabq", "Qabq" },
             { "SM", "San Marino" },
-            { "Qabn", "Qabn" },
             { "SN", "Senegal" },
-            { "Qabo", "Qabo" },
             { "SO", "Somali\u00eb" },
             { "arn", "Mapudungun" },
-            { "Qabl", "Qabl" },
-            { "Qabm", "Qabm" },
             { "arp", "Arapaho" },
-            { "Qabj", "Qabj" },
             { "type.nu.taml", "traditionele Tamil cijfers" },
             { "SR", "Suriname" },
             { "aro", "Araona" },
-            { "Qabk", "Qabk" },
             { "SS", "Zuid-Soedan" },
             { "ST", "Sao Tom\u00e9 en Principe" },
             { "arq", "Algerijns Arabisch" },
@@ -646,7 +633,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "SX", "Sint-Maarten" },
             { "SY", "Syri\u00eb" },
             { "yao", "Yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "eSwatini" },
             { "arw", "Arawak" },
             { "arz", "Egyptisch Arabisch" },
             { "ary", "Marokkaans Arabisch" },
@@ -659,35 +646,21 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "TC", "Turks- en Caicoseilanden" },
             { "yav", "Yangben" },
             { "TD", "Tsjaad" },
-            { "Qaag", "Qaag" },
-            { "Qaah", "Qaah" },
             { "TF", "Franse Gebieden in de zuidelijke Indische Oceaan" },
             { "ase", "Amerikaanse Gebarentaal" },
-            { "Qaae", "Qaae" },
             { "TG", "Togo" },
-            { "Qaaf", "Qaaf" },
             { "TH", "Thailand" },
-            { "Qaac", "Qaac" },
-            { "Qaad", "Qaad" },
             { "TJ", "Tadzjikistan" },
-            { "Qaaa", "Qaaa" },
             { "029", "Caribisch gebied" },
             { "TK", "Tokelau" },
-            { "Qaab", "Qaab" },
             { "TL", "Oost-Timor" },
             { "ybb", "Yemba" },
-            { "Qaao", "Qaao" },
             { "type.co.searchjl", "Zoeken op eerste Hangul-medeklinker" },
             { "TM", "Turkmenistan" },
-            { "Qaap", "Qaap" },
             { "%%BOONT", "Boontling" },
             { "TN", "Tunesi\u00eb" },
-            { "Qaam", "Qaam" },
             { "TO", "Tonga" },
-            { "Qaan", "Qaan" },
             { "%%NULIK", "Modern Volap\u00fck" },
-            { "Qaak", "Qaak" },
-            { "Qaal", "Qaal" },
             { "TR", "Turkije" },
             { "TT", "Trinidad en Tobago" },
             { "TV", "Tuvalu" },
@@ -718,20 +691,14 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "UN", "Verenigde Naties" },
             { "US", "Verenigde Staten" },
             { "haw", "Hawa\u00efaans" },
-            { "Qabx", "Qabx" },
             { "%%1959ACAD", "Academisch" },
-            { "Qabv", "Qabv" },
+            { "%%IVANCHOV", "Ivanchov" },
             { "type.co.gb2312han", "Vereenvoudigd-Chinese sorteervolgorde - GB2312" },
-            { "Qabw", "Qabw" },
             { "UY", "Uruguay" },
             { "prg", "Oudpruisisch" },
-            { "Qabt", "Qabt" },
             { "UZ", "Oezbekistan" },
-            { "Qabu", "Qabu" },
             { "tzm", "Tamazight (Centraal-Marokko)" },
-            { "Qabr", "Qabr" },
             { "type.co.stroke", "Streeksorteervolgorde" },
-            { "Qabs", "Qabs" },
             { "nnh", "Ngiemboon" },
             { "VA", "Vaticaanstad" },
             { "pro", "Oudproven\u00e7aals" },
@@ -740,6 +707,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Britse Maagdeneilanden" },
             { "VI", "Amerikaanse Maagdeneilanden" },
+            { "%%LEMOSIN", "Lemosin" },
             { "Soyo", "Soyombo" },
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
@@ -766,7 +734,9 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.nu.mtei", "Meetei Mayek cijfers" },
             { "wal", "Wolaytta" },
             { "was", "Washo" },
+            { "XA", "Pseudo-Accenten" },
             { "war", "Waray" },
+            { "XB", "Pseudo-Bidi" },
             { "awa", "Awadhi" },
             { "061", "Polynesi\u00eb" },
             { "%%KSCOR", "Standaardspelling" },
@@ -811,7 +781,10 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.nu.telu", "Telugu cijfers" },
             { "lou", "Louisiana-Creools" },
             { "loz", "Lozi" },
+            { "%%FONKIRSH", "Fonkirsh" },
             { "Nkgb", "Naxi Geba" },
+            { "%%ASANTE", "Asante" },
+            { "%%AUVERN", "Auvern" },
             { "jmc", "Machame" },
             { "hif", "Fijisch Hindi" },
             { "type.nu.hansfin", "vereenvoudigd Chinese financi\u00eble cijfers" },
@@ -858,6 +831,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.d0.fwidth", "Volledige breedte" },
             { "sbp", "Sangu" },
             { "lui", "Luiseno" },
+            { "%%GRITAL", "Grital" },
             { "nyn", "Nyankole" },
             { "nym", "Nyamwezi" },
             { "lun", "Lunda" },
@@ -905,7 +879,9 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "sdh", "Pahlavani" },
             { "ay", "Aymara" },
             { "az", "Azerbeidzjaans" },
+            { "Rohg", "Hanifi Rohingya" },
             { "Khoj", "Khojki" },
+            { "%%CISAUP", "Cisaup" },
             { "%%OSOJS", "Oseacco/Osojane-dialect" },
             { "%%UNIFON", "Unifon fonetisch alfabet" },
             { "ba", "Basjkiers" },
@@ -1001,10 +977,13 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.m0.bgn", "BGN" },
             { "umb", "Umbundu" },
             { "fr", "Frans" },
+            { "%%AKUAPEM", "Akuapem" },
             { "sid", "Sidamo" },
             { "fy", "Fries" },
             { "ga", "Iers" },
+            { "Wcho", "Wancho" },
             { "gd", "Schots-Gaelisch" },
+            { "Gong", "Gunjala Gondi" },
             { "gl", "Galicisch" },
             { "Gonm", "Masaram Gondi" },
             { "gn", "Guaran\u00ed" },
@@ -1034,6 +1013,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "id", "Indonesisch" },
             { "type.nu.tibt", "Tibetaanse cijfers" },
             { "ie", "Interlingue" },
+            { "%%GASCON", "Gascon" },
             { "ig", "Igbo" },
             { "ii", metaValue_ii },
             { "frm", "Middelfrans" },
@@ -1112,8 +1092,8 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "type.nu.lana", "Tai Tham Hora cijfers" },
             { "lt", "Litouws" },
             { "lu", "Luba-Katanga" },
+            { "sog", metaValue_sog },
             { "lv", "Lets" },
-            { "sog", "Sogdisch" },
             { "mg", "Malagassisch" },
             { "mh", "Marshallees" },
             { "type.co.ducet", "standaard Unicode-sorteervolgorde" },
@@ -1141,6 +1121,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "nl", "Nederlands" },
             { "nn", "Noors - Nynorsk" },
             { "no", "Noors" },
+            { "%%PROVENC", "Provenc" },
             { "nr", "Zuid-Ndbele" },
             { "type.nu.modi", "Modi cijfers" },
             { "Osge", metaValue_osa },
@@ -1162,7 +1143,6 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "kaw", "Kawi" },
             { "dtp", "Dusun" },
             { "or", metaValue_or },
-            { "Modi", "Modi" },
             { "os", "Ossetisch" },
             { "%%ALALC97", "Romanisering ALA-LC, editie 1997" },
             { "bpy", "Bishnupriya" },
@@ -1257,6 +1237,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "%%NEDIS", "Natisone-dialect" },
             { "sv", "Zweeds" },
             { "sw", "Swahili" },
+            { "type.nu.wcho", "Wancho cijfers" },
             { "type.nu.hantfin", "traditioneel Chinese financi\u00eble cijfers" },
             { "ibb", "Ibibio" },
             { "iba", "Iban" },
@@ -1280,9 +1261,9 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "dyo", "Jola-Fonyi" },
             { "type.nu.jpan", "Japanse cijfers" },
             { "tr", "Turks" },
+            { "Cakm", metaValue_ccp },
             { "ts", "Tsonga" },
             { "swb", "Shimaore" },
-            { "Cakm", "Chakma" },
             { "tt", "Tataars" },
             { "%%XSISTEMO", "X-sistemo" },
             { "dyu", "Dyula" },
@@ -1291,6 +1272,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "%%BISKE", "San Giorgio/Bila-dialect" },
             { "150", "Europa" },
             { "151", "Oost-Europa" },
+            { "type.nu.rohg", "Hanifi Rohingya cijfers" },
             { "type.nu.mathsanb", "schreefloze vette wiskundige cijfers" },
             { "154", "Noord-Europa" },
             { "dzg", "Dazaga" },
@@ -1333,6 +1315,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "wa", "Waals" },
             { "gag", "Gagaoezisch" },
             { "syr", "Syrisch" },
+            { "type.nu.gong", "Gunjala Gondi cijfers" },
             { "Grek", metaValue_el },
             { "gan", "Ganyu" },
             { "kiu", "Kirmanck\u00ee" },
@@ -1352,11 +1335,13 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "mni", metaValue_mni },
             { "Latn", "Latijns" },
             { "Latg", "Gaelisch Latijns" },
+            { "Nand", "Nandinagari" },
             { "type.nu.hans", "vereenvoudigd Chinese cijfers" },
             { "type.nu.hant", "traditioneel Chinese cijfers" },
             { "xh", "Xhosa" },
             { "type.nu.romanlow", "kleine Romeinse cijfers" },
             { "byn", "Blin" },
+            { "Dogr", "Dogra" },
             { "%%PAMAKA", "Pamaka" },
             { "Lyci", "Lycisch" },
             { "osa", metaValue_osa },
@@ -1389,9 +1374,9 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "%%MONOTON", "Monotonaal" },
             { "Geor", metaValue_ka },
             { "Shrd", "Sharada" },
+            { "%%LENGADOC", "Lengadoc" },
             { "kmb", "Kimbundu" },
             { "type.nu.jpanfin", "Japanse financi\u00eble cijfers" },
-            { "Cham", "Cham" },
             { "gez", "Ge\u2019ez" },
             { "mrj", "West-Mari" },
             { "Syrn", "Oost-Aramees" },
@@ -1421,6 +1406,7 @@ public class LocaleNames_nl extends OpenListResourceBundle {
             { "Sund", metaValue_su },
             { "vep", "Wepsisch" },
             { "kpe", metaValue_kpe },
+            { "%%GRCLASS", "Grclass" },
             { "type.nu.khmr", "Khmer cijfers" },
             { "Tirh", "Tirhuta" },
             { "ilo", "Iloko" },
