@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -96,7 +96,6 @@ public class LocaleNames_pt extends OpenListResourceBundle {
         final String metaValue_ban = "balin\u00eas";
         final String metaValue_bax = "bamum";
         final String metaValue_bug = "bugin\u00eas";
-        final String metaValue_chr = "cherokee";
         final String metaValue_got = "g\u00f3tico";
         final String metaValue_nqo = "n\u2019ko";
         final String metaValue_phn = "fen\u00edcio";
@@ -115,6 +114,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "Tagb", "tagbanwa" },
             { "Zsye", "Emoji" },
             { "%%NJIVA", "dialeto gniva/njiva" },
+            { "ccp", "Chakma" },
             { "egy", "eg\u00edpcio arcaico" },
             { "raj", "rajastani" },
             { "Phag", "phags-pa" },
@@ -131,7 +131,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "AF", "Afeganist\u00e3o" },
             { "AG", "Ant\u00edgua e Barbuda" },
             { "type.ca.ethiopic", "Calend\u00e1rio Et\u00edope" },
-            { "AI", "Anguilla" },
+            { "AI", "Anguila" },
             { "key.tz", "Fuso hor\u00e1rio" },
             { "AL", "Alb\u00e2nia" },
             { "AM", "Arm\u00eania" },
@@ -183,7 +183,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "mzn", "mazandarani" },
             { "CD", "Congo - Kinshasa" },
             { "CF", "Rep\u00fablica Centro-Africana" },
-            { "CG", "Congo - Brazzaville" },
+            { "CG", "Rep\u00fablica do Congo" },
             { "CH", "Su\u00ed\u00e7a" },
             { "CI", "Costa do Marfim" },
             { "CK", "Ilhas Cook" },
@@ -225,7 +225,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "type.d0.hwidth", metaValue_type_d0_fwidth },
             { "pag", "pangasin\u00e3" },
             { "pal", "p\u00e1lavi" },
-            { "EA", "Ceuta e Melilha" },
+            { "EA", "Ceuta e Melilla" },
             { "chb", "chibcha" },
             { "pam", "pampanga" },
             { "EC", "Equador" },
@@ -242,7 +242,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "chm", "mari" },
             { "chp", "chipewyan" },
             { "cho", "choctaw" },
-            { "chr", metaValue_chr },
+            { "chr", "cheroqui" },
             { "ER", "Eritreia" },
             { "ES", "Espanha" },
             { "ET", "Eti\u00f3pia" },
@@ -387,7 +387,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "Thaa", "thaana" },
             { "MA", "Marrocos" },
             { "MC", "M\u00f4naco" },
-            { "MD", "Mold\u00e1via" },
+            { "MD", "Moldova" },
             { "ME", "Montenegro" },
             { "MF", "S\u00e3o Martinho" },
             { "lam", "lamba" },
@@ -396,7 +396,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "MH", "Ilhas Marshall" },
             { "ale", "ale\u00fate" },
             { "type.nu.vaii", "D\u00edgitos vai" },
-            { "MK", "Maced\u00f4nia" },
+            { "MK", "Maced\u00f4nia do Norte" },
             { "ML", "Mali" },
             { "MM", "Mianmar (Birm\u00e2nia)" },
             { "MN", "Mong\u00f3lia" },
@@ -407,9 +407,9 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "MR", "Maurit\u00e2nia" },
             { "MS", "Montserrat" },
             { "MT", "Malta" },
-            { "type.m0.ungegn", "UNGEGN" },
+            { "type.m0.ungegn", "Translitera\u00e7\u00e3o UN GEGN" },
             { "MU", "Maur\u00edcio" },
-            { "alt", "altai do sul" },
+            { "alt", "altai meridional" },
             { "MV", "Maldivas" },
             { "MW", "Malaui" },
             { "MX", "M\u00e9xico" },
@@ -418,6 +418,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "MZ", "Mo\u00e7ambique" },
             { "Phli", "phli" },
             { "NA", "Nam\u00edbia" },
+            { "202", "\u00c1frica Subsaariana" },
             { "type.ca.hebrew", "Calend\u00e1rio Hebraico" },
             { "type.co.dictionary", "Ordem do dicion\u00e1rio" },
             { "NC", "Nova Caled\u00f4nia" },
@@ -430,7 +431,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "Phlp", "phlp" },
             { "NI", "Nicar\u00e1gua" },
             { "Hmng", "pahawh hmong" },
-            { "NL", "Holanda" },
+            { "NL", "Pa\u00edses Baixos" },
             { "NO", "Noruega" },
             { "NP", "Nepal" },
             { "NR", "Nauru" },
@@ -528,7 +529,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "SS", "Sud\u00e3o do Sul" },
             { "ST", "S\u00e3o Tom\u00e9 e Pr\u00edncipe" },
             { "SV", "El Salvador" },
-            { "ars", "\u00e1rabe - N\u00e9gede" },
+            { "ars", "\u00e1rabe n\u00e9gede" },
             { "SX", "Sint Maarten" },
             { "SY", "S\u00edria" },
             { "yao", "yao" },
@@ -539,7 +540,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "asa", "asu" },
             { "type.ms.ussystem", "Sistema de medi\u00e7\u00e3o americano" },
             { "021", "Am\u00e9rica Setentrional" },
-            { "TC", "Ilhas Turks e Caicos" },
+            { "TC", "Ilhas Turcas e Caicos" },
             { "yav", "yangben" },
             { "TD", "Chade" },
             { "TF", "Territ\u00f3rios Franceses do Sul" },
@@ -615,7 +616,9 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "WS", "Samoa" },
             { "wal", "wolaytta" },
             { "was", "washo" },
+            { "XA", "Pseudossotaques" },
             { "war", "waray" },
+            { "XB", "Pseudobidi" },
             { "awa", "awadhi" },
             { "061", "Polin\u00e9sia" },
             { "XK", "Kosovo" },
@@ -809,7 +812,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "bgn", "bal\u00fachi ocidental" },
             { "yue", "canton\u00eas" },
             { "fo", "fero\u00eas" },
-            { "type.m0.bgn", "BGN" },
+            { "type.m0.bgn", "Translitera\u00e7\u00e3o BGN EUA" },
             { "umb", "umbundu" },
             { "fr", "franc\u00eas" },
             { "sid", "sidamo" },
@@ -860,7 +863,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "Sara", "sarati" },
             { "doi", "dogri" },
             { "bkm", "kom" },
-            { "sma", "sami do sul" },
+            { "sma", "sami meridional" },
             { "jv", metaValue_jv },
             { "Shaw", "shaviano" },
             { "mad", "madur\u00eas" },
@@ -1001,7 +1004,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "bss", "akoose" },
             { "rw", "quiniaruanda" },
             { "zbl", "s\u00edmbolos blis" },
-            { "kea", "kabuverdianu" },
+            { "kea", "crioulo cabo-verdiano" },
             { "mic", "miquemaque" },
             { "suk", "sukuma" },
             { "sa", "s\u00e2nscrito" },
@@ -1181,7 +1184,7 @@ public class LocaleNames_pt extends OpenListResourceBundle {
             { "Glag", "glagol\u00edtico" },
             { "gil", "gilbert\u00eas" },
             { "%%KKCOR", "ortografia comum" },
-            { "Cher", metaValue_chr },
+            { "Cher", "cherokee" },
             { "car", "caribe" },
             { "cay", "cayuga" },
             { "type.nu.tamldec", "Algarismos t\u00e2mil" },
