@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -86,7 +86,6 @@ public class LocaleNames_si extends OpenListResourceBundle {
         final String metaValue_la = "\u0dbd\u0dad\u0dd2\u0db1\u0dca";
         final String metaValue_lo = "\u0dbd\u0dcf\u0d95";
         final String metaValue_ml = "\u0db8\u0dbd\u0dba\u0dcf\u0dbd\u0db8\u0dca";
-        final String metaValue_or = "\u0d94\u0dbb\u0dd2\u0dba\u0dcf";
         final String metaValue_si = "\u0dc3\u0dd2\u0d82\u0dc4\u0dbd";
         final String metaValue_ta = "\u0daf\u0dd9\u0db8\u0dc5";
         final String metaValue_te = "\u0dad\u0dd9\u0dc5\u0dd2\u0d9f\u0dd4";
@@ -116,7 +115,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "AO", "\u0d87\u0db1\u0dca\u0d9c\u0ddd\u0dbd\u0dcf\u0dc0" },
             { "AQ", "\u0d87\u0db1\u0dca\u0da7\u0dcf\u0d9a\u0dca\u0da7\u0dd2\u0d9a\u0dcf\u0dc0" },
             { "AR", "\u0d86\u0dbb\u0dca\u0da2\u0dd9\u0db1\u0dca\u0da7\u0dd2\u0db1\u0dcf\u0dc0" },
-            { "AS", "\u0d87\u0db8\u0dbb\u0dd2\u0d9a\u0dcf\u0db1\u0dd4 \u0dc3\u0dd0\u0db8\u0ddd\u0dc0\u0dcf\u0dc0" },
+            { "AS", "\u0d87\u0db8\u0dbb\u0dd2\u0d9a\u0dcf\u0db1\u0dd4 \u0dc3\u0dd0\u0db8\u0ddd\u0dc0\u0dcf" },
             { "AT", "\u0d94\u0dc3\u0dca\u0da7\u0dca\u200d\u0dbb\u0dd2\u0dba\u0dcf\u0dc0" },
             { "AU", "\u0d95\u0dc3\u0dca\u0da7\u0dca\u200d\u0dbb\u0dda\u0dbd\u0dd2\u0dba\u0dcf\u0dc0" },
             { "AW", "\u0d85\u0dbb\u0dd6\u0db6\u0dcf" },
@@ -170,7 +169,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "CW", "\u0d9a\u0dd4\u0dbb\u0d9a\u0dcf\u0dc0\u0ddd" },
             { "CX", "\u0d9a\u0dca\u200d\u0dbb\u0dd2\u0dc3\u0dca\u0db8\u0dc3\u0dca \u0daf\u0dd6\u0db4\u0dad" },
             { "CY", "\u0dc3\u0dba\u0dd2\u0db4\u0dca\u200d\u0dbb\u0dc3\u0dba" },
-            { "CZ", "\u0da0\u0dd9\u0d9a\u0dca \u0da2\u0db1\u0dbb\u0da2\u0dba" },
+            { "CZ", "\u0da0\u0dd9\u0da0\u0dd2\u0dba\u0dcf\u0dc0" },
             { "eka", "\u0d91\u0d9a\u0da2\u0dd4\u0d9a\u0dca" },
             { "DE", "\u0da2\u0dbb\u0dca\u0db8\u0db1\u0dd2\u0dba" },
             { "ace", "\u0d85\u0da0\u0dba\u0dd2\u0db1\u0dd2\u0dc3\u0dca" },
@@ -266,7 +265,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "IR", "\u0d89\u0dbb\u0dcf\u0db1\u0dba" },
             { "IS", "\u0d85\u0dba\u0dd2\u0dc3\u0dca\u0dbd\u0db1\u0dca\u0dad\u0dba" },
             { "IT", "\u0d89\u0dad\u0dcf\u0dbd\u0dd2\u0dba" },
-            { "Zmth", "\u0d9c\u0db1\u0dd2\u0dad\u0db8\u0dba \u0dc3\u0d82\u0d9a\u0dda\u0dad" },
+            { "Zmth", "\u0d9c\u0dab\u0dd2\u0dad\u0db8\u0dba \u0dc3\u0d82\u0d9a\u0dda\u0dad" },
             { "type.nu.thai", "\u0dad\u0dcf\u0dba\u0dd2 \u0d89\u0dbd\u0d9a\u0dca\u0d9a\u0db8\u0dca" },
             { "type.nu.beng", "\u0db6\u0dd9\u0d82\u0d9c\u0dcf\u0dbd\u0dd2 \u0d89\u0dbd\u0d9a\u0dca\u0d9a\u0db8\u0dca" },
             { "JE", "\u0da2\u0dbb\u0dca\u0dc3\u0dd2" },
@@ -344,6 +343,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "MY", "\u0db8\u0dd0\u0dbd\u0dda\u0dc3\u0dd2\u0dba\u0dcf\u0dc0" },
             { "MZ", "\u0db8\u0ddc\u0dc3\u0dd0\u0db8\u0dca\u0db6\u0dd2\u0d9a\u0dca" },
             { "NA", "\u0db1\u0dd0\u0db8\u0dd3\u0db6\u0dd2\u0dba\u0dcf\u0dc0" },
+            { "202", "\u0d8b\u0db4-\u0dc3\u0dc4\u0dbb\u0dcf\u0db1\u0dd4 \u0d85\u0db4\u0dca\u200d\u0dbb\u0dd2\u0d9a\u0dcf\u0dc0" },
             { "type.ca.hebrew", "\u0dc4\u0dd3\u0db6\u0df2 \u0daf\u0dd2\u0db1 \u0daf\u0dbb\u0dca\u0dc1\u0db1\u0dba" },
             { "type.co.dictionary", "\u0dc1\u0db6\u0dca\u0daf\u0d9a\u0ddd\u0dc2 \u0db4\u0dd9\u0dc5\u0d9c\u0dd0\u0dc3\u0dca\u0db8" },
             { "NC", "\u0db1\u0dc0 \u0d9a\u0dd0\u0dbd\u0dd2\u0da9\u0ddd\u0db1\u0dd2\u0dba\u0dcf\u0dc0" },
@@ -585,7 +585,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "ce", "\u0da0\u0dd9\u0da0\u0dca\u0db1\u0dd2\u0dba\u0dcf\u0db1\u0dd4" },
             { "ch", "\u0da0\u0db8\u0ddc\u0dbb\u0ddc" },
             { "co", "\u0d9a\u0ddd\u0dc3\u0dd2\u0d9a\u0dcf\u0db1\u0dd4" },
-            { "Orya", metaValue_or },
+            { "Orya", "\u0d94\u0dbb\u0dd2\u0dba\u0dcf" },
             { "cs", "\u0da0\u0dd9\u0d9a\u0dca" },
             { "cu", "\u0da0\u0dbb\u0dca\u0da0\u0dca \u0dc3\u0dca\u0dbd\u0dd0\u0dc0\u0dd2\u0d9a\u0dca" },
             { "cv", "\u0da0\u0dc0\u0dda\u0dc2\u0dca" },
@@ -737,7 +737,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "mer", "\u0db8\u0dd9\u0dbb\u0dd4" },
             { "type.nu.armn", "\u0d87\u0db8\u0dbb\u0dd2\u0d9a\u0dcf\u0db1\u0dd4 \u0dc3\u0d82\u0d9b\u0dca\u200d\u0dba\u0dcf\u0d82\u0d9a\u0db1" },
             { "om", "\u0d94\u0dbb\u0ddc\u0db8\u0ddd" },
-            { "or", metaValue_or },
+            { "or", "\u0d94\u0da9\u0dd2\u0dba\u0dcf" },
             { "os", "\u0d94\u0dc3\u0dd2\u0da7\u0dd9\u0d9a\u0dca" },
             { "kbd", "\u0d9a\u0db6\u0dcf\u0dbb\u0dca\u0da9\u0dd2\u0dba\u0db1\u0dca" },
             { "mfe", "\u0db8\u0ddc\u0dbb\u0dd2\u0dc3\u0dca\u0dba\u0dd9\u0db8\u0dca" },
@@ -830,7 +830,7 @@ public class LocaleNames_si extends OpenListResourceBundle {
             { "155", "\u0db6\u0da7\u0dc4\u0dd2\u0dbb \u0dba\u0dd4\u0dbb\u0ddd\u0db4\u0dba" },
             { "ug", "\u0d8b\u0dba\u0dd2\u0d9c\u0dbb\u0dca" },
             { "Kore", metaValue_ko },
-            { "Zyyy", "\u0db4\u0ddc\u0daf\u0dd4." },
+            { "Zyyy", "\u0db4\u0ddc\u0daf\u0dd4" },
             { "uk", "\u0dba\u0dd4\u0d9a\u0dca\u0dbb\u0dda\u0db1\u0dd2\u0dba\u0dcf\u0db1\u0dd4" },
             { "ur", "\u0d8b\u0dbb\u0dca\u0daf\u0dd4" },
             { "xal", "\u0d9a\u0dbd\u0dca\u0db8\u0dd2\u0d9a\u0dca" },
