@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -310,14 +310,6 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                "Falklandeilande-tyd",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Bhoetan-tyd",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia-standaardtyd",
                "",
@@ -326,6 +318,14 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                "Apia-tyd",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Bhoetan-tyd",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru-tyd",
                "",
@@ -566,12 +566,12 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Colombi\u00eb-standaardtyd",
+        final String[] Australia_Eastern = new String[] {
+               "Oostelike Australiese standaardtyd",
                "",
-               "Colombi\u00eb-somertyd",
+               "Oostelike Australiese dagligtyd",
                "",
-               "Colombi\u00eb-tyd",
+               "Oostelike Australiese tyd",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -582,12 +582,12 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Oostelike Australiese standaardtyd",
+        final String[] Colombia = new String[] {
+               "Colombi\u00eb-standaardtyd",
                "",
-               "Oostelike Australiese dagligtyd",
+               "Colombi\u00eb-somertyd",
                "",
-               "Oostelike Australiese tyd",
+               "Colombi\u00eb-tyd",
                "",
             };
         final String[] Chile = new String[] {
@@ -1046,12 +1046,12 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Noordwes-Meksiko-standaardtyd",
+        final String[] Volgograd = new String[] {
+               "Wolgograd-standaardtyd",
                "",
-               "Noordwes-Meksiko-dagligtyd",
+               "Wolgograd-somertyd",
                "",
-               "Noordwes-Meksiko-tyd",
+               "Wolgograd-tyd",
                "",
             };
         final String[] Easter = new String[] {
@@ -1062,6 +1062,14 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                "Paaseiland-tyd",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Noordwes-Meksiko-standaardtyd",
+               "",
+               "Noordwes-Meksiko-dagligtyd",
+               "",
+               "Noordwes-Meksiko-tyd",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville-tyd",
                "",
@@ -1214,14 +1222,6 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                "Samara-tyd",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Pyongyang-tyd",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Indi\u00eb-standaardtyd",
                "",
@@ -1252,7 +1252,16 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1335,7 +1344,6 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1445,12 +1453,12 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sao Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "Onbekende stad" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1509,9 +1517,19 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Efate", "Efate" },
             { "timezone.excity.Asia/Aqtobe", "Aqtobe" },
             { "Asia/Vladivostok", Vladivostok },
+            { "timezone.excity.Atlantic/St_Helena", "Sint Helena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "America/Cayman", America_Eastern },
@@ -1668,7 +1686,6 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goosebaai" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1768,7 +1785,7 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Djibouti", "Djiboeti" },
             { "America/Tegucigalpa", America_Central },
             { "timezone.excity.America/Recife", "Recife" },
-            { "timezone.excity.Pacific/Wallis", "Wallis" },
+            { "timezone.excity.Pacific/Wallis", "Mata-Utu" },
             { "America/Miquelon", Pierre_Miquelon },
             { "timezone.excity.Africa/Porto-Novo", "Porto-Novo" },
             { "timezone.excity.Antarctica/Palmer", "Palmer" },
@@ -1876,7 +1893,7 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1901,7 +1918,7 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Athene" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1923,6 +1940,7 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jerusalem" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riaad" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2085,7 +2103,7 @@ public class TimeZoneNames_af extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "Sint Thomas" },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Istanbul" },
             { "timezone.excity.Europe/Sarajevo", "Sarajevo" },
