@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -135,17 +135,27 @@ public class TimeZoneNames_en_001 extends TimeZoneNamesBundle {
             { "America/Indianapolis", America_Eastern },
             { "Pacific/Honolulu",
                 new String[] {
-                    "",
+                    "Hawaii Standard Time",
                     "\u2205\u2205\u2205",
-                    "",
+                    "Hawaii Daylight Time",
                     "\u2205\u2205\u2205",
-                    "",
+                    "Hawaii Time",
                     "\u2205\u2205\u2205",
                 }
             },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "UTC",
                 new String[] {
                     "",
@@ -163,6 +173,16 @@ public class TimeZoneNames_en_001 extends TimeZoneNamesBundle {
             { "America/El_Salvador", America_Central },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/Coral_Harbour", America_Eastern },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
             { "America/Guatemala", America_Central },
@@ -188,8 +208,8 @@ public class TimeZoneNames_en_001 extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "America/Nome", Alaska },
             { "America/Ojinaga", America_Mountain },
+            { "America/Nome", Alaska },
             { "America/Tegucigalpa", America_Central },
             { "America/Rainy_River", America_Central },
             { "SystemV/AST4", Atlantic },
@@ -222,10 +242,8 @@ public class TimeZoneNames_en_001 extends TimeZoneNamesBundle {
             { "America/Grand_Turk", America_Eastern },
             { "America/Metlakatla", Alaska },
             { "America/Pangnirtung", America_Eastern },
-            { "EST", America_Eastern },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Creston", America_Mountain },
-            { "MST", America_Mountain },
             { "America/Punta_Arenas",
                 new String[] {
                     "",
@@ -245,8 +263,8 @@ public class TimeZoneNames_en_001 extends TimeZoneNamesBundle {
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
             { "America/Moncton", Atlantic },
+            { "America/Blanc-Sablon", Atlantic },
             { "America/Indiana/Winamac", America_Eastern },
             { "SystemV/MST7MDT", America_Mountain },
             { "America/St_Vincent", Atlantic },
@@ -265,27 +283,17 @@ public class TimeZoneNames_en_001 extends TimeZoneNamesBundle {
             { "CST6CDT", America_Central },
             { "SystemV/HST10",
                 new String[] {
-                    "",
+                    "Hawaii Standard Time",
                     "\u2205\u2205\u2205",
-                    "",
+                    "Hawaii Daylight Time",
                     "\u2205\u2205\u2205",
-                    "",
+                    "Hawaii Time",
                     "\u2205\u2205\u2205",
                 }
             },
-            { "America/Menominee", America_Central },
             { "America/Yakutat", Alaska },
+            { "America/Menominee", America_Central },
             { "America/Adak", Hawaii_Aleutian },
-            { "HST",
-                new String[] {
-                    "",
-                    "\u2205\u2205\u2205",
-                    "",
-                    "\u2205\u2205\u2205",
-                    "",
-                    "\u2205\u2205\u2205",
-                }
-            },
             { "America/Resolute", America_Central },
             { "SystemV/YST9YDT", Alaska },
             { "Europe/Ulyanovsk",
@@ -324,8 +332,8 @@ public class TimeZoneNames_en_001 extends TimeZoneNamesBundle {
                 }
             },
             { "America/Boise", America_Mountain },
-            { "America/North_Dakota/New_Salem", America_Central },
             { "EST5EDT", America_Eastern },
+            { "America/North_Dakota/New_Salem", America_Central },
             { "America/Dawson_Creek", America_Mountain },
             { "America/St_Thomas", Atlantic },
             { "Atlantic/Bermuda", Atlantic },
