@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -73,12 +73,22 @@ public class TimeZoneNames_en_IN extends TimeZoneNamesBundle {
         final String[] India = new String[] {
                "India Standard Time",
                "IST",
-               "",
-               "",
-               "",
-               "",
+               "India Daylight Time",
+               "IDT",
+               "India Time",
+               "IT",
             };
         final Object[][] data = new Object[][] {
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "UTC",
                 new String[] {
                     "",
@@ -142,6 +152,16 @@ public class TimeZoneNames_en_IN extends TimeZoneNamesBundle {
                     "",
                 }
             },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Europe/Saratov",
                 new String[] {
                     "",
