@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "falklandsko vrijeme",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "butansko vrijeme",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "standardno vrijeme Apije",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "vrijeme Apije",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "butansko vrijeme",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "vrijeme Naurua",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "kolumbijsko standardno vrijeme",
+        final String[] Australia_Eastern = new String[] {
+               "isto\u010dnoaustralsko standardno vrijeme",
                "",
-               "kolumbijsko ljetno vrijeme",
+               "isto\u010dnoaustralsko ljetno vrijeme",
                "",
-               "kolumbijsko vrijeme",
+               "isto\u010dnoaustralsko vrijeme",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "isto\u010dnoaustralsko standardno vrijeme",
+        final String[] Colombia = new String[] {
+               "kolumbijsko standardno vrijeme",
                "",
-               "isto\u010dnoaustralsko ljetno vrijeme",
+               "kolumbijsko ljetno vrijeme",
                "",
-               "isto\u010dnoaustralsko vrijeme",
+               "kolumbijsko vrijeme",
                "",
             };
         final String[] Chile = new String[] {
@@ -710,14 +710,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "paragvajsko vrijeme",
                "",
             };
-        final String[] Casey = new String[] {
-               "vrijeme Caseyja",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "malezijsko vrijeme",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "sjeverozapadno meksi\u010dko standardno vrijeme",
+        final String[] Volgograd = new String[] {
+               "volgogradsko standardno vrijeme",
                "",
-               "sjeverozapadno meksi\u010dko ljetno vrijeme",
+               "volgogradsko ljetno vrijeme",
                "",
-               "sjeverozapadno meksi\u010dko vrijeme",
+               "volgogradsko vrijeme",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "vrijeme Uskr\u0161njeg otoka",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "sjeverozapadno meksi\u010dko standardno vrijeme",
+               "",
+               "sjeverozapadno meksi\u010dko ljetno vrijeme",
+               "",
+               "sjeverozapadno meksi\u010dko vrijeme",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "vrijeme Dumont-d\u2019Urvillea",
                "",
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                "samarsko vrijeme",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "pjongjan\u0161ko vrijeme",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "indijsko vrijeme",
                "",
@@ -1268,7 +1260,16 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1285,7 +1286,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Phoenix" },
-            { "timezone.excity.America/Antigua", "Antigua" },
             { "timezone.excity.Europe/Ljubljana", "Ljubljana" },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "timezone.excity.Pacific/Marquesas", "Marki\u017eansko oto\u010dje" },
@@ -1351,7 +1351,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1460,12 +1459,12 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sao Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "Nepoznati grad" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1525,8 +1524,17 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luksemburg" },
             { "America/Cayman", America_Eastern },
@@ -1683,7 +1691,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1720,6 +1727,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1891,7 +1899,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1915,7 +1923,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Atena" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1937,7 +1945,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jeruzalem" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Rijad" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2097,7 +2105,7 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Istanbul" },
             { "America/Rio_Branco", Acre },
@@ -2212,7 +2220,6 @@ public class TimeZoneNames_hr extends TimeZoneNamesBundle {
             { "timezone.excity.America/Iqaluit", "Iqaluit" },
             { "America/Winnipeg", America_Central },
             { "timezone.excity.Europe/Amsterdam", "Amsterdam" },
-            { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
             { "timezone.excity.Pacific/Saipan", "Saipan" },
             { "timezone.excity.Indian/Cocos", "Kokosovi otoci" },
             { "timezone.excity.Australia/Currie", "Currie" },
