@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "falkland-szigeteki id\u0151",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "but\u00e1ni id\u0151",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "apiai t\u00e9li id\u0151",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "apiai id\u0151",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "but\u00e1ni id\u0151",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "naurui id\u0151",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "kolumbiai t\u00e9li id\u0151",
+        final String[] Australia_Eastern = new String[] {
+               "kelet-ausztr\u00e1liai t\u00e9li id\u0151",
                "",
-               "kolumbiai ny\u00e1ri id\u0151",
+               "kelet-ausztr\u00e1liai ny\u00e1ri id\u0151",
                "",
-               "kolumbiai id\u0151",
+               "kelet-ausztr\u00e1liai id\u0151",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "kelet-ausztr\u00e1liai t\u00e9li id\u0151",
+        final String[] Colombia = new String[] {
+               "kolumbiai t\u00e9li id\u0151",
                "",
-               "kelet-ausztr\u00e1liai ny\u00e1ri id\u0151",
+               "kolumbiai ny\u00e1ri id\u0151",
                "",
-               "kelet-ausztr\u00e1liai id\u0151",
+               "kolumbiai id\u0151",
                "",
             };
         final String[] Chile = new String[] {
@@ -1054,12 +1054,12 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "\u00e9szaknyugat-mexik\u00f3i z\u00f3naid\u0151",
+        final String[] Volgograd = new String[] {
+               "volgogr\u00e1di t\u00e9li id\u0151",
                "",
-               "\u00e9szaknyugat-mexik\u00f3i ny\u00e1ri id\u0151",
+               "volgogr\u00e1di ny\u00e1ri id\u0151",
                "",
-               "\u00e9szaknyugat-mexik\u00f3i id\u0151",
+               "volgogr\u00e1di id\u0151",
                "",
             };
         final String[] Easter = new String[] {
@@ -1070,6 +1070,14 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "h\u00fasv\u00e9t-szigeti id\u0151z\u00f3na",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "\u00e9szaknyugat-mexik\u00f3i z\u00f3naid\u0151",
+               "",
+               "\u00e9szaknyugat-mexik\u00f3i ny\u00e1ri id\u0151",
+               "",
+               "\u00e9szaknyugat-mexik\u00f3i id\u0151",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "dumont-d\u2019Urville-i id\u0151",
                "",
@@ -1222,14 +1230,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                "Szamarai id\u0151",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "phenjani id\u0151",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "indiai t\u00e9li id\u0151",
                "",
@@ -1260,7 +1260,16 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1345,7 +1354,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1455,12 +1463,12 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "Ismeretlen v\u00e1ros" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1521,8 +1529,17 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Szent Ilona" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "America/Cayman", America_Eastern },
@@ -1679,7 +1696,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1716,6 +1732,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kosztanaj" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1888,7 +1905,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1912,7 +1929,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Ath\u00e9n" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1934,6 +1951,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jeruzs\u00e1lem" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Rij\u00e1d" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2094,7 +2112,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Isztanbul" },
             { "America/Rio_Branco", Acre },
