@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "Ora e Ishujve Falkland",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Ora e Butanit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Ora standarde e Apias",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "Ora e Apias",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Ora e Butanit",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Ora e Naurus\u00eb",
                "",
@@ -567,23 +567,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "",
             };
         final String[] Kyrgystan = new String[] {
-               "Ora e Kirgistanit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Colombia = new String[] {
-               "Ora standarde e Kolumbis\u00eb",
-               "",
-               "Ora verore e Kolumbis\u00eb",
-               "",
-               "Ora e Kolumbis\u00eb",
-               "",
-            };
-        final String[] French_Guiana = new String[] {
-               "Ora e Guajan\u00ebs Franceze",
+               "Ora e Kirgizis\u00eb",
                "",
                "",
                "",
@@ -598,6 +582,22 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "Ora e Australis\u00eb Lindore",
                "",
             };
+        final String[] French_Guiana = new String[] {
+               "Ora e Guajan\u00ebs Franceze",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Colombia = new String[] {
+               "Ora standarde e Kolumbis\u00eb",
+               "",
+               "Ora verore e Kolumbis\u00eb",
+               "",
+               "Ora e Kolumbis\u00eb",
+               "",
+            };
         final String[] Chile = new String[] {
                "Ora standarde e Kilit",
                "",
@@ -710,14 +710,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "Ora e Paraguait",
                "",
             };
-        final String[] Casey = new String[] {
-               "Ora e Kejsit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "Ora e Malajzis\u00eb",
                "",
@@ -751,7 +743,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "",
             };
         final String[] Marshall_Islands = new String[] {
-               "Ora e Ishujve Marshall\u00eb",
+               "Ora e Ishujve Marshall",
                "",
                "",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Ora standarde e Meksik\u00ebs Veriper\u00ebndimore",
+        final String[] Volgograd = new String[] {
+               "Ora standarde e Volgogradit",
                "",
-               "Ora verore e Meksik\u00ebs Veriper\u00ebndimore",
+               "Ora verore e Volgogradit",
                "",
-               "Ora e Meksik\u00ebs Veriper\u00ebndimore",
+               "Ora e Volgogradit",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "Ora e Ishullit t\u00eb Pashk\u00ebs",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Ora standarde e Meksik\u00ebs Veriper\u00ebndimore",
+               "",
+               "Ora verore e Meksik\u00ebs Veriper\u00ebndimore",
+               "",
+               "Ora e Meksik\u00ebs Veriper\u00ebndimore",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Ora e Dumont-d\u2019Urvil\u00ebs",
                "",
@@ -1087,11 +1087,11 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "",
             };
         final String[] Greenland_Western = new String[] {
-               "Ora standarde e Grenland\u00ebs Per\u00ebndimore",
+               "Ora standarde e Gr\u00ebnland\u00ebs Per\u00ebndimore",
                "",
-               "Ora verore e Grenland\u00ebs Per\u00ebndimore",
+               "Ora verore e Gr\u00ebnland\u00ebs Per\u00ebndimore",
                "",
-               "Ora e Grenland\u00ebs Per\u00ebndimore",
+               "Ora e Gr\u00ebnland\u00ebs Per\u00ebndimore",
                "",
             };
         final String[] Ecuador = new String[] {
@@ -1161,7 +1161,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
         final String[] Alaska = new String[] {
                "Ora standarde e Alask\u00ebs",
                "",
-               "Ora verore e Alsask\u00ebs",
+               "Ora verore e Alask\u00ebs",
                "",
                "Ora e Alask\u00ebs",
                "",
@@ -1207,11 +1207,11 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "",
             };
         final String[] Brasilia = new String[] {
-               "Ora standarde e Brasil\u00ebs",
+               "Ora standarde e Brazilis\u00eb",
                "",
-               "Ora verore e Brasil\u00ebs",
+               "Ora verore e Brazilis\u00eb",
                "",
-               "Ora e Brasil\u00ebs",
+               "Ora e Brazilis\u00eb",
                "",
             };
         final String[] Anadyr = new String[] {
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                "Ora e Samar\u00ebs",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Ora e Penianit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Ora standarde e Indis\u00eb",
                "",
@@ -1268,7 +1260,16 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1353,7 +1354,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vankuver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1432,7 +1432,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Pacific/Enderbury", Phoenix_Islands },
             { "America/Juneau", Alaska },
             { "America/Indiana/Vevay", America_Eastern },
-            { "timezone.excity.America/Grenada", "Grenad\u00eb" },
+            { "timezone.excity.America/Grenada", "Granad\u00eb" },
             { "timezone.excity.Asia/Phnom_Penh", "Pnom-Pen" },
             { "timezone.excity.Europe/Rome", "Rom\u00eb" },
             { "timezone.excity.Asia/Hebron", "Hebron" },
@@ -1466,12 +1466,12 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sao-Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "Nju-Jork" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Akra" },
             { "timezone.excity.Etc/Unknown", "Qytet i panjohur" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Dhule" },
             { "timezone.excity.America/Grand_Turk", "Turku i Madh" },
             { "America/Yakutat", Alaska },
@@ -1531,26 +1531,35 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Efate", "Efate" },
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
             { "Asia/Vladivostok", Vladivostok },
-            { "timezone.excity.Atlantic/St_Helena", "Sh\u00ebn-Helen\u00eb" },
+            { "timezone.excity.Atlantic/St_Helena", "Sh\u00ebn-Elen\u00eb" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotong\u00eb" },
             { "timezone.excity.Europe/Luxembourg", "Luksemburg" },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Baghdad", Arabian },
-            { "timezone.excity.Asia/Bahrain", "Bahrein" },
+            { "timezone.excity.Asia/Bahrain", "Bahrejn" },
             { "timezone.excity.Indian/Mahe", "Mahe" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
             { "timezone.excity.Europe/Isle_of_Man", "Ishulli i Manit" },
             { "Pacific/Saipan", Chamorro },
-            { "timezone.excity.America/Curacao", "Kura\u00e7ao" },
+            { "timezone.excity.America/Curacao", "Kurasao" },
             { "timezone.excity.Pacific/Nauru", "Nauru" },
             { "timezone.excity.Pacific/Pago_Pago", "Pago-Pago" },
             { "Antarctica/Rothera", Rothera },
-            { "timezone.excity.America/Guyana", "Gujan\u00eb" },
+            { "timezone.excity.America/Guyana", "Guajan\u00eb" },
             { "Asia/Damascus", Europe_Eastern },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "Paris" },
@@ -1694,7 +1703,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Gjiri i Pat\u00ebs" },
             { "timezone.excity.America/Eirunepe", "Ejrunep" },
             { "timezone.excity.America/Los_Angeles", "Los Anxhelos" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Kujaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1867,7 +1875,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Dawson", "Douson" },
             { "timezone.excity.Africa/Abidjan", "Abixhan" },
             { "America/Barbados", Atlantic },
-            { "timezone.excity.America/Guadeloupe", "Guadalupe" },
+            { "timezone.excity.America/Guadeloupe", "Guadelup\u00eb" },
             { "timezone.excity.Africa/Freetown", "Fritaun" },
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "timezone.excity.America/Fortaleza", "Fortaleza" },
@@ -1906,7 +1914,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1914,7 +1922,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Maceio", "Makejo" },
             { "timezone.excity.America/Guayaquil", "Guajakuil" },
             { "Africa/Ndjamena", Africa_Western },
-            { "timezone.excity.America/St_Vincent", "Sh\u00ebn-Vinsent" },
+            { "timezone.excity.America/St_Vincent", "Sh\u00ebn-Vincent" },
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
@@ -1931,8 +1939,8 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Athin\u00eb" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
             { "timezone.excity.America/Indiana/Knox", "Knoks, Indiana" },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1954,7 +1962,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jerusalem" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riad" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2058,7 +2066,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Sakhalin", "Sakalin" },
             { "Pacific/Kiritimati", Line_Islands },
             { "timezone.excity.America/Nipigon", "Nipigon" },
-            { "timezone.excity.Europe/Guernsey", "Guernsej" },
+            { "timezone.excity.Europe/Guernsey", "Gernsej" },
             { "timezone.excity.America/Argentina/San_Luis", "Sh\u00ebn-Luis" },
             { "timezone.excity.Europe/Riga", "Rig\u00eb" },
             { "timezone.excity.America/Araguaina", "Araguajana" },
@@ -2098,7 +2106,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Africa/Luanda", Africa_Western },
             { "timezone.excity.Europe/Mariehamn", "Mariehamn" },
             { "timezone.excity.America/St_Johns", "Sh\u00ebn-Gjon" },
-            { "timezone.excity.America/St_Barthelemy", "Sh\u00ebn-Bartolemeo" },
+            { "timezone.excity.America/St_Barthelemy", "Sen-Bartelemi" },
             { "timezone.excity.America/Santiago", "Santiago" },
             { "Asia/Muscat", Gulf },
             { "Asia/Bahrain", Arabian },
@@ -2118,7 +2126,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "Sh\u00ebn-Tomas" },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Stamboll" },
             { "America/Rio_Branco", Acre },
@@ -2232,7 +2240,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.America/Iqaluit", "Ikaluit" },
             { "America/Winnipeg", America_Central },
             { "timezone.excity.Europe/Amsterdam", "Amsterdam" },
-            { "timezone.excity.Atlantic/Bermuda", "Bermud\u00eb" },
+            { "timezone.excity.Atlantic/Bermuda", "Bermude" },
             { "timezone.excity.Pacific/Saipan", "Saipan" },
             { "timezone.excity.Indian/Cocos", "Kokos" },
             { "timezone.excity.Australia/Currie", "Kuri" },
